
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_k_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.175457'}

wordnet_terms_k = [
    'ka',
    'kaaba',
    'kabala',
    'kabbala',
    'kabbalah',
    'kabbalism',
    'kabbalist',
    'kabbalistic',
    'kabob',
    'kabolin',
    'kabul',
    'kach',
    'kachaturian',
    'kachin',
    'kachina',
    'kachinic',
    'kadai',
    'kadikoy',
    'kaffir',
    'kaffiyeh',
    'kafir',
    'kafiri',
    'kafka',
    'kafkaesque',
    'kafocin',
    'kaftan',
    'kahikatea',
    'kahlua',
    'kahn',
    'kahoolawe',
    'kail',
    'kainite',
    'kainogenesis',
    'kaiser',
    'kakatoe',
    'kakemono',
    'kaki',
    'kakutani',
    'kalahari',
    'kalamazoo',
    'kalansuwa',
    'kalantas',
    'kalapooia',
    'kalapooian',
    'kalapuya',
    'kalapuyan',
    'kalashnikov',
    'kale',
    'kaleidoscope',
    'kaleidoscopic',
    'kaleidoscopical',
    'kalemia',
    'kali',
    'kalian',
    'kalif',
    'kalimantan',
    'kalinin',
    'kaliph',
    'kaliuresis',
    'kalka',
    'kalki',
    'kalmia',
    'kalotermes',
    'kalotermitidae',
    'kalpac',
    'kaluga',
    'kalumpang',
    'kaluresis',
    'kama',
    'kamarupan',
    'kamasutra',
    'kamba',
    'kamchatka',
    'kameez',
    'kamet',
    'kami',
    'kamia',
    'kamikaze',
    'kampala',
    'kampong',
    'kampuchea',
    'kampuchean',
    'kanaf',
    'kanamycin',
    'kananga',
    'kanara',
    'kanarese',
    'kanawha',
    'kanchanjanga',
    'kanchenjunga',
    'kanchil',
    'kandahar',
    'kandinski',
    'kandinsky',
    'kandy',
    'kangaroo',
    'kangaroos',
    'kannada',
    'kansa',
    'kansan',
    'kansas',
    'kansu',
    'kant',
    'kantian',
    'kantrex',
    'kanzu',
    'kaochlor',
    'kaoliang',
    'kaolin',
    'kaoline',
    'kaolinite',
    'kaon',
    'kaopectate',
    'kapeika',
    'kapeikas',
    'kaph',
    'kapital',
    'kapok',
    'kappa',
    'kapsiki',
    'kapuka',
    'kara',
    'karabiner',
    'karachi',
    'karaites',
    'karakalpak',
    'karakoram',
    'karakul',
    'karaoke',
    'karat',
    'karate',
    'karbala',
    'karelia',
    'karelian',
    'karen',
    'karenic',
    'karl',
    'karlfeldt',
    'karloff',
    'karma',
    'karnataka',
    'karok',
    'karpov',
    'karsavina',
    'kartik',
    'kartikeya',
    'karttika',
    'karttikeya',
    'karyokinesis',
    'karyokinetic',
    'karyolymph',
    'karyolysis',
    'karyon',
    'karyoplasm',
    'karyotype',
    'kasai',
    'kasbah',
    'kasha',
    'kashag',
    'kashmir',
    'kashmiri',
    'kasparov',
    'kassite',
    'kassites',
    'kastler',
    'kat',
    'katabatic',
    'katabolic',
    'katabolism',
    'katamorphism',
    'katar',
    'katari',
    'kate',
    'katharevusa',
    'katharine',
    'katharobe',
    'katharobic',
    'katharometer',
    'katharsis',
    'kathleen',
    'kathmandu',
    'katmandu',
    'katowice',
    'katsina',
    'katsura',
    'katsuwonidae',
    'katsuwonus',
    'kattegatt',
    'katydid',
    'katydids',
    'katzenjammer',
    'kauai',
    'kaufman',
    'kaunas',
    'kaunda',
    'kauri',
    'kaury',
    'kava',
    'kavakava',
    'kavrin',
    'kawaka',
    'kayak',
    'kayaked',
    'kayo',
    'kayoed',
    'kazak',
    'kazakh',
    'kazakhs',
    'kazakhstan',
    'kazakhstani',
    'kazakstan',
    'kazan',
    'kazimir',
    'kazoo',
    'kazoos',
    'kb',
    'kbit',
    'kbo',
    'kc',
    'kea',
    'kean',
    'keaton',
    'keats',
    'keb',
    'kebab',
    'keble',
    'kechua',
    'kechuan',
    'ked',
    'kedah',
    'kedgeree',
    'keel',
    'keelboat',
    'keeled',
    'keelson',
    'keen',
    'keenly',
    'keenness',
    'keep',
    'keeper',
    'keepeth',
    'keeping',
    'keeps',
    'keepsake',
    'keeshond',
    'keflex',
    'keflin',
    'keftab',
    'keg',
    'kegful',
    'kegs',
    'keister',
    'kekchi',
    'kekule',
    'kelantan',
    'keller',
    'kellogg',
    'kelly',
    'keloid',
    'kelp',
    'kelpie',
    'kelps',
    'kelpwort',
    'kelpy',
    'kelt',
    'kelter',
    'kelvin',
    'kemadrin',
    'kemal',
    'kempt',
    'ken',
    'kenaf',
    'kenalog',
    'kendal',
    'kendall',
    'kendrew',
    'kennan',
    'kennedia',
    'kennedy',
    'kennedya',
    'kennel',
    'kennelly',
    'kenneth',
    'kennewick',
    'kenning',
    'keno',
    'kenogenesis',
    'kenosis',
    'kent',
    'kentan',
    'kentish',
    'kentuckian',
    'kentucky',
    'kenya',
    'kenyan',
    'kenyapithecus',
    'kenyata',
    'keokuk',
    'kepi',
    'kepler',
    'kept',
    'kera',
    'keratalgia',
    'keratectasia',
    'keratin',
    'keratinisation',
    'keratinise',
    'keratinization',
    'keratinize',
    'keratinized',
    'keratitis',
    'keratoacanthoma',
    'keratocele',
    'keratoconjunctivitis',
    'keratoconus',
    'keratoderma',
    'keratodermia',
    'keratohyalin',
    'keratoiritis',
    'keratomalacia',
    'keratomycosis',
    'keratonosis',
    'keratonosus',
    'keratoplasty',
    'keratoscleritis',
    'keratoscope',
    'keratoscopy',
    'keratosis',
    'keratotomy',
    'kerb',
    'kerbala',
    'kerbela',
    'kerbstone',
    'kerchief',
    'kerensky',
    'kerfuffle',
    'kerion',
    'kern',
    'kernel',
    'kernels',
    'kernicterus',
    'kernite',
    'kerosene',
    'kerosine',
    'kerouac',
    'kerugma',
    'kerygma',
    'kesey',
    'kestrel',
    'ketalar',
    'ketamine',
    'ketch',
    'ketchup',
    'keteleeria',
    'ketembilla',
    'ketoacidosis',
    'ketoaciduria',
    'ketohexose',
    'ketone',
    'ketonemia',
    'ketones',
    'ketonuria',
    'ketoprofen',
    'ketorolac',
    'ketose',
    'ketosis',
    'ketosteroid',
    'kettering',
    'kettle',
    'kettledrum',
    'kettledrums',
    'kettleful',
    'kettles',
    'ketubim',
    'keurboom',
    'key',
    'keyboard',
    'keyboardist',
    'keyboards',
    'keycard',
    'keyed',
    'keyhole',
    'keyless',
    'keynes',
    'keynesian',
    'keynesianism',
    'keynote',
    'keynotes',
    'keypad',
    'keys',
    'keystone',
    'keystroke',
    'keystrokes',
    'kg',
    'kgb',
    'khabarovsk',
    'khachaturian',
    'khadafy',
    'khaddar',
    'khadi',
    'khaki',
    'khakis',
    'khalif',
    'khalifah',
    'khalka',
    'khalkha',
    'khalsa',
    'khama',
    'khamsin',
    'khamti',
    'khan',
    'khanate',
    'khanty',
    'kharkiv',
    'kharkov',
    'khartoum',
    'khat',
    'khaya',
    'khayyam',
    'khedive',
    'khepera',
    'khesari',
    'khi',
    'khimar',
    'khios',
    'khirghiz',
    'khmer',
    'khoikhoi',
    'khoikhoin',
    'khoisan',
    'khomeini',
    'khoum',
    'khoums',
    'khowar',
    'khrushchev',
    'khuen',
    'khufu',
    'khukuri',
    'khyber',
    'khz',
    'ki',
    'kiaat',
    'kiang',
    'kib',
    'kibbitz',
    'kibble',
    'kibbutz',
    'kibbutznik',
    'kibe',
    'kibibit',
    'kibibits',
    'kibibyte',
    'kibibytes',
    'kibit',
    'kibitz',
    'kibitzer',
    'kibosh',
    'kichaga',
    'kichai',
    'kick',
    'kickapoo',
    'kickback',
    'kicked',
    'kicker',
    'kicking',
    'kickoff',
    'kicks',
    'kickshaw',
    'kicksorter',
    'kickstand',
    'kid',
    'kidd',
    'kidded',
    'kiddie',
    'kiddy',
    'kidnap',
    'kidnaper',
    'kidnapped',
    'kidnapper',
    'kidnappers',
    'kidnapping',
    'kidnappings',
    'kidney',
    'kidneys',
    'kids',
    'kidskin',
    'kierkegaard',
    'kieselguhr',
    'kieserite',
    'kieslowski',
    'kiev',
    'kigali',
    'kiggelaria',
    'kike',
    'kikladhes',
    'kildeer',
    'kilderkin',
    'kiley',
    'kilimanjaro',
    'kiliwa',
    'kiliwi',
    'kill',
    'killable',
    'killdeer',
    'killed',
    'killer',
    'killers',
    'killifish',
    'killing',
    'killjoy',
    'kills',
    'kiln',
    'kilns',
    'kilo',
    'kilobit',
    'kilobits',
    'kilobyte',
    'kilobytes',
    'kilocalorie',
    'kilocycle',
    'kilogram',
    'kilograms',
    'kilohertz',
    'kiloliter',
    'kilolitre',
    'kilometer',
    'kilometers',
    'kilometre',
    'kiloton',
    'kilovolt',
    'kilowatt',
    'kilroy',
    'kilt',
    'kilter',
    'kilts',
    'kimberley',
    'kimberlite',
    'kimono',
    'kin',
    'kina',
    'kinaesthesia',
    'kinaesthesis',
    'kinaesthetic',
    'kinanesthesia',
    'kinase',
    'kinchinjunga',
    'kind',
    'kindergarten',
    'kindergartener',
    'kindergartner',
    'kindhearted',
    'kindheartedness',
    'kindle',
    'kindled',
    'kindliness',
    'kindling',
    'kindly',
    'kindness',
    'kindred',
    'kinds',
    'kine',
    'kinematics',
    'kinescope',
    'kinesiology',
    'kinesis',
    'kinesthesia',
    'kinesthesis',
    'kinesthetic',
    'kinesthetics',
    'kinetic',
    'kinetics',
    'kinetochore',
    'kinetoscope',
    'kinetosis',
    'kinfolk',
    'king',
    'kingbird',
    'kingbolt',
    'kingcup',
    'kingdom',
    'kingdoms',
    'kingfish',
    'kingfisher',
    'kingfishers',
    'kinglet',
    'kinglets',
    'kinglike',
    'kingly',
    'kingmaker',
    'kingpin',
    'kings',
    'kingship',
    'kingsley',
    'kingsnake',
    'kingston',
    'kingstown',
    'kingwood',
    'kinin',
    'kink',
    'kinkajou',
    'kinks',
    'kinky',
    'kino',
    'kinosternidae',
    'kinosternon',
    'kinsey',
    'kinsfolk',
    'kinshasa',
    'kinship',
    'kinsman',
    'kinsperson',
    'kinswoman',
    'kinyarwanda',
    'kiosk',
    'kiowa',
    'kip',
    'kipling',
    'kiplingesque',
    'kipper',
    'kippur',
    'kirchhoff',
    'kirchner',
    'kirghiz',
    'kirghizia',
    'kirghizstan',
    'kirgiz',
    'kirgizia',
    'kirgizstan',
    'kiribati',
    'kirk',
    'kirkia',
    'kirkuk',
    'kirpan',
    'kirsch',
    'kirtle',
    'kishar',
    'kishinev',
    'kishke',
    'kislev',
    'kismat',
    'kismet',
    'kiss',
    'kissed',
    'kisser',
    'kisses',
    'kissimmee',
    'kissing',
    'kissinger',
    'kisumu',
    'kiswahili',
    'kit',
    'kitakyushu',
    'kitambilla',
    'kitbag',
    'kitchen',
    'kitchener',
    'kitchenette',
    'kitchens',
    'kitchenware',
    'kite',
    'kited',
    'kitembilla',
    'kites',
    'kith',
    'kiting',
    'kits',
    'kitsch',
    'kitschy',
    'kittee',
    'kitten',
    'kittened',
    'kittenish',
    'kittiwake',
    'kitts',
    'kittul',
    'kitty',
    'kitul',
    'kivu',
    'kiwi',
    'kiwis',
    'kkk',
    'klaipeda',
    'klamath',
    'klan',
    'klansman',
    'klaproth',
    'klavern',
    'klavier',
    'klaxon',
    'klebsiella',
    'klee',
    'kleenex',
    'klein',
    'kleist',
    'kleptomania',
    'kleptomaniac',
    'klick',
    'klimt',
    'kline',
    'klinefelter',
    'klondike',
    'klopstock',
    'klorvess',
    'klotho',
    'kludge',
    'klutz',
    'klux',
    'kluxer',
    'klystron',
    'klyuchevskaya',
    'km',
    'knack',
    'knacker',
    'knackered',
    'knackwurst',
    'knap',
    'knapsack',
    'knapweed',
    'knave',
    'knavery',
    'knavish',
    'knawe',
    'knawel',
    'knead',
    'kneaded',
    'kneading',
    'kneads',
    'knee',
    'kneecap',
    'kneecapped',
    'kneel',
    'kneeler',
    'kneeling',
    'kneepan',
    'knees',
    'knell',
    'knesset',
    'knesseth',
    'knew',
    'knickerbockers',
    'knickers',
    'knickknack',
    'knickknackery',
    'knicks',
    'knife',
    'knifed',
    'knifelike',
    'knight',
    'knighted',
    'knighthood',
    'knightia',
    'knightliness',
    'knightly',
    'knights',
    'kniphofia',
    'knish',
    'knit',
    'knitted',
    'knitter',
    'knitting',
    'knitwear',
    'knitwork',
    'knives',
    'knob',
    'knobbed',
    'knobble',
    'knobbly',
    'knobby',
    'knobkerrie',
    'knobkerry',
    'knobs',
    'knock',
    'knockabout',
    'knockdown',
    'knocked',
    'knocker',
    'knocking',
    'knockoff',
    'knockout',
    'knocks',
    'knockwurst',
    'knoll',
    'knossos',
    'knot',
    'knotgrass',
    'knothole',
    'knots',
    'knotted',
    'knottiness',
    'knotting',
    'knotty',
    'knout',
    'know',
    'knowable',
    'knower',
    'knowing',
    'knowingly',
    'knowingness',
    'knowledge',
    'knowledgeability',
    'knowledgeable',
    'knowledgeableness',
    'known',
    'knows',
    'knox',
    'knoxville',
    'knuckle',
    'knuckleball',
    'knucklebones',
    'knucklehead',
    'knuckler',
    'knuckles',
    'knucks',
    'knut',
    'ko',
    'koala',
    'koalas',
    'koan',
    'koasati',
    'kob',
    'kobe',
    'kobenhavn',
    'kobo',
    'kobos',
    'kobus',
    'koch',
    'kochia',
    'kodiak',
    'koellia',
    'koestler',
    'kogia',
    'kohl',
    'kohleria',
    'kohlrabi',
    'koine',
    'koinonia',
    'kokka',
    'kola',
    'kolam',
    'kolami',
    'kolkata',
    'kolkhoz',
    'kolkhoznik',
    'kolkwitzia',
    'koln',
    'kolonia',
    'komi',
    'komondor',
    'konakri',
    'kong',
    'kongfuze',
    'kongo',
    'konini',
    'konoe',
    'konoye',
    'konqueror',
    'koodoo',
    'kook',
    'kookaburra',
    'kookie',
    'kooky',
    'koopmans',
    'kopeck',
    'kopecks',
    'kopek',
    'kopiyka',
    'kopiykas',
    'kopje',
    'koppie',
    'kor',
    'koran',
    'koranic',
    'korbut',
    'korchnoi',
    'korda',
    'kordofan',
    'kordofanian',
    'kore',
    'korea',
    'korean',
    'koreans',
    'korinthos',
    'koruna',
    'korzybski',
    'kos',
    'kosciusko',
    'kosciuszko',
    'kosher',
    'kosma',
    'kosovo',
    'kosteletzya',
    'kota',
    'kotar',
    'kotex',
    'koto',
    'kotoko',
    'kotow',
    'koudou',
    'koumiss',
    'koussevitzky',
    'kovacs',
    'kovna',
    'kovno',
    'koweit',
    'kowhai',
    'kowtow',
    'kowtowing',
    'kp',
    'kph',
    'kr',
    'kra',
    'kraal',
    'kraft',
    'krait',
    'kraits',
    'krakatao',
    'krakatau',
    'krakatoa',
    'krakau',
    'krakow',
    'krasner',
    'kraurosis',
    'kraut',
    'krauthead',
    'krebs',
    'kreisler',
    'kremlin',
    'krigia',
    'krill',
    'kris',
    'krishna',
    'krishnaism',
    'krispies',
    'kriti',
    'kroeber',
    'krona',
    'krone',
    'kronecker',
    'kronenbergers',
    'kroon',
    'kropotkin',
    'kroto',
    'krubi',
    'kruger',
    'krummhorn',
    'krupp',
    'krypterophaneron',
    'krypton',
    'ks',
    'kshatriya',
    'kshatriyas',
    'kt',
    'ku',
    'kuala',
    'kuan',
    'kuangchou',
    'kublai',
    'kubrick',
    'kuchean',
    'kudos',
    'kudu',
    'kudzu',
    'kuenlun',
    'kuhn',
    'kui',
    'kuiper',
    'kukenaam',
    'kuki',
    'kulanapan',
    'kulun',
    'kumasi',
    'kumis',
    'kummel',
    'kumquat',
    'kumquats',
    'kung',
    'kunlun',
    'kunzite',
    'kuomintang',
    'kura',
    'kurakkan',
    'kurchee',
    'kurchi',
    'kurd',
    'kurdish',
    'kurdistan',
    'kurds',
    'kurosawa',
    'kuroshio',
    'kurrajong',
    'kurrat',
    'kursk',
    'kurta',
    'kuru',
    'kurus',
    'kurux',
    'kusan',
    'kush',
    'kutch',
    'kutuzov',
    'kuvasz',
    'kuvi',
    'kuwait',
    'kuwaiti',
    'kuznets',
    'kv',
    'kvass',
    'kvetch',
    'kw',
    'kwa',
    'kwacha',
    'kwai',
    'kwajalein',
    'kwakiutl',
    'kwangchow',
    'kwangju',
    'kwangtung',
    'kwannon',
    'kwanza',
    'kwanzaa',
    'kwashiorkor',
    'kweek',
    'kwela',
    'kwell',
    'ky',
    'kyanite',
    'kyat',
    'kyd',
    'kylie',
    'kylix',
    'kymograph',
    'kyoto',
    'kyphosidae',
    'kyphosis',
    'kyphosus',
    'kyphotic',
    'kyrgyzstan',
    'kyrgyzstani',
    'kyushu',
    'kyyiv']




#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_m_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.187457'}

wordnet_terms_m = [
    'ma',
    'maalox',
    'maar',
    'maarianhamina',
    'mac',
    'macabre',
    'macaca',
    'macadam',
    'macadamia',
    'macadamise',
    'macadamize',
    'macadamized',
    'macamba',
    'macao',
    'macaque',
    'macaroni',
    'macaronic',
    'macaroon',
    'macarthur',
    'macau',
    'macaulay',
    'macaw',
    'macaws',
    'macbeth',
    'maccabaeus',
    'maccabees',
    'macdonald',
    'macdowell',
    'mace',
    'macebearer',
    'macedoine',
    'macedon',
    'macedonia',
    'macedonian',
    'macedonians',
    'macer',
    'macerate',
    'macerated',
    'macerates',
    'maceration',
    'macerative',
    'maces',
    'macgregor',
    'macguffin',
    'mach',
    'machaeranthera',
    'machete',
    'machiavelli',
    'machiavellian',
    'machiavellianism',
    'machicolate',
    'machicolation',
    'machilid',
    'machilidae',
    'machilids',
    'machinate',
    'machination',
    'machinator',
    'machine',
    'machined',
    'machinelike',
    'machinery',
    'machines',
    'machining',
    'machinist',
    'machismo',
    'machmeter',
    'macho',
    'macintosh',
    'mack',
    'mackem',
    'mackenzie',
    'mackerel',
    'mackerels',
    'mackinaw',
    'mackintosh',
    'mackle',
    'macleaya',
    'macleish',
    'macleod',
    'maclura',
    'macon',
    'maconnais',
    'macoun',
    'macowanites',
    'macrame',
    'macrencephalic',
    'macrencephalous',
    'macrencephaly',
    'macro',
    'macrobiotic',
    'macrobiotics',
    'macrocephalic',
    'macrocephalon',
    'macrocephalous',
    'macrocephaly',
    'macrocheira',
    'macroclemys',
    'macrocosm',
    'macrocosmic',
    'macrocyte',
    'macrocytes',
    'macrocytosis',
    'macrodactylus',
    'macrodantin',
    'macroeconomic',
    'macroeconomics',
    'macroeconomist',
    'macroevolution',
    'macroglia',
    'macroglossia',
    'macromolecular',
    'macromolecule',
    'macromolecules',
    'macron',
    'macronectes',
    'macrophage',
    'macrophages',
    'macropodidae',
    'macropus',
    'macrorhamphosidae',
    'macroscopic',
    'macroscopical',
    'macrosporangium',
    'macrospore',
    'macrothelypteris',
    'macrotis',
    'macrotus',
    'macrotyloma',
    'macrouridae',
    'macrozamia',
    'macrozoarces',
    'macruridae',
    'macula',
    'macular',
    'maculate',
    'maculation',
    'maculatum',
    'macule',
    'macumba',
    'macushla',
    'mad',
    'madagascan',
    'madagascar',
    'madake',
    'madam',
    'madame',
    'madcap',
    'madden',
    'maddened',
    'maddening',
    'madder',
    'madderwort',
    'made',
    'madeira',
    'madeiras',
    'mademoiselle',
    'madhouse',
    'madia',
    'madison',
    'madman',
    'madmen',
    'madnep',
    'madness',
    'madonna',
    'madoqua',
    'madras',
    'madrasa',
    'madrasah',
    'madrasas',
    'madreporaria',
    'madrepore',
    'madrid',
    'madrigal',
    'madrigaling',
    'madrigalist',
    'madrigals',
    'madrilene',
    'madrona',
    'madrono',
    'madwoman',
    'madwort',
    'maeandra',
    'maelstrom',
    'maenad',
    'maestro',
    'maeterlinck',
    'mafa',
    'maffia',
    'mafia',
    'mafioso',
    'mag',
    'magadhan',
    'magazine',
    'magazines',
    'magdalen',
    'magdalena',
    'magellan',
    'magellanic',
    'magenta',
    'maggot',
    'maggoty',
    'magh',
    'magha',
    'maghreb',
    'magi',
    'magic',
    'magical',
    'magician',
    'magicicada',
    'magilp',
    'maginot',
    'magister',
    'magisterial',
    'magistracy',
    'magistrate',
    'magistrature',
    'maglev',
    'magma',
    'magna',
    'magnanimity',
    'magnanimous',
    'magnanimousness',
    'magnate',
    'magnates',
    'magnesia',
    'magnesite',
    'magnesium',
    'magnet',
    'magnetic',
    'magnetically',
    'magnetics',
    'magnetisation',
    'magnetise',
    'magnetised',
    'magnetism',
    'magnetite',
    'magnetization',
    'magnetize',
    'magnetized',
    'magneto',
    'magnetograph',
    'magnetohydrodynamics',
    'magnetometer',
    'magnetomotive',
    'magneton',
    'magnetosphere',
    'magnetron',
    'magnets',
    'magnificat',
    'magnification',
    'magnificence',
    'magnificent',
    'magnificently',
    'magnifico',
    'magnified',
    'magnifier',
    'magnifies',
    'magnify',
    'magnifying',
    'magniloquence',
    'magniloquent',
    'magnitude',
    'magnitudes',
    'magnolia',
    'magnoliaceae',
    'magnolias',
    'magnoliid',
    'magnoliidae',
    'magnoliophyta',
    'magnoliopsid',
    'magnoliopsida',
    'magnum',
    'magog',
    'magpie',
    'magpies',
    'magritte',
    'maguey',
    'magus',
    'magyar',
    'magyarorszag',
    'maha',
    'mahabharata',
    'mahabharatam',
    'mahabharatum',
    'mahagua',
    'mahal',
    'mahan',
    'maharaja',
    'maharajah',
    'maharanee',
    'maharani',
    'maharashtra',
    'mahatma',
    'mahayana',
    'mahayanism',
    'mahayanist',
    'mahdi',
    'mahdism',
    'mahdist',
    'mahgrib',
    'mahican',
    'mahimahi',
    'mahjong',
    'mahler',
    'mahlstick',
    'mahoe',
    'mahogany',
    'mahomet',
    'mahonia',
    'mahound',
    'mahout',
    'mahratta',
    'mahrattas',
    'mahratti',
    'mahuang',
    'maia',
    'maianthemum',
    'maid',
    'maiden',
    'maidenhair',
    'maidenhead',
    'maidenhood',
    'maidenlike',
    'maidenliness',
    'maidenly',
    'maidens',
    'maidhood',
    'maidism',
    'maidservant',
    'maidu',
    'maiduguri',
    'maiger',
    'maigre',
    'maigret',
    'maikoa',
    'mail',
    'mailbag',
    'mailboat',
    'mailbox',
    'maildrop',
    'mailed',
    'mailer',
    'mailers',
    'mailing',
    'mailings',
    'maillol',
    'maillot',
    'mailman',
    'mails',
    'mailsorter',
    'maim',
    'maimed',
    'maimer',
    'maimonides',
    'main',
    'maine',
    'mainer',
    'mainframe',
    'mainland',
    'mainline',
    'mainlining',
    'mainly',
    'mainmast',
    'mains',
    'mainsail',
    'mainsheet',
    'mainspring',
    'mainstay',
    'mainstream',
    'mainstreamed',
    'maintain',
    'maintainable',
    'maintained',
    'maintainer',
    'maintaining',
    'maintains',
    'maintenance',
    'maintenon',
    'maiolica',
    'maisonette',
    'maisonnette',
    'maitland',
    'maitre',
    'maitreya',
    'maize',
    'maja',
    'majagua',
    'majestic',
    'majesty',
    'majidae',
    'majolica',
    'major',
    'majora',
    'majorana',
    'majorca',
    'majorette',
    'majoring',
    'majority',
    'majors',
    'majuscular',
    'majuscule',
    'majuscules',
    'mak',
    'makaira',
    'makalu',
    'makarios',
    'makataimeshekiakiak',
    'make',
    'makedonija',
    'makeover',
    'maker',
    'makeready',
    'makers',
    'makes',
    'makeshift',
    'makeshifts',
    'makeup',
    'makeweight',
    'makin',
    'making',
    'makings',
    'mako',
    'makomako',
    'maksim',
    'makuta',
    'mal',
    'malabo',
    'malabsorption',
    'malacanthidae',
    'malacca',
    'malachi',
    'malachias',
    'malachite',
    'malacia',
    'malaclemys',
    'malacologist',
    'malacology',
    'malaconotinae',
    'malacopterygian',
    'malacopterygii',
    'malacosoma',
    'malacostraca',
    'malacostracan',
    'malacothamnus',
    'maladaptive',
    'maladies',
    'maladjusted',
    'maladjustive',
    'maladjustment',
    'maladroit',
    'maladroitness',
    'malady',
    'malaga',
    'malahini',
    'malaise',
    'malamud',
    'malamute',
    'malamutes',
    'malanga',
    'malaprop',
    'malapropism',
    'malapropos',
    'malar',
    'malaria',
    'malarial',
    'malarkey',
    'malarky',
    'malathion',
    'malawi',
    'malawian',
    'malaxis',
    'malay',
    'malaya',
    'malayalam',
    'malayan',
    'malaysia',
    'malaysian',
    'malcolmia',
    'malcontent',
    'maldivan',
    'maldive',
    'maldives',
    'maldivian',
    'maldon',
    'male',
    'maleate',
    'maleberry',
    'malebranche',
    'malecite',
    'maledict',
    'malediction',
    'malefactor',
    'malefic',
    'maleficence',
    'maleficent',
    'maleic',
    'malemute',
    'maleness',
    'maleo',
    'maleos',
    'males',
    'maleseet',
    'malevich',
    'malevolence',
    'malevolency',
    'malevolent',
    'malfeasance',
    'malfeasant',
    'malformation',
    'malformations',
    'malformed',
    'malfunction',
    'malfunctioning',
    'malheur',
    'mali',
    'malian',
    'malice',
    'malicious',
    'maliciously',
    'maliciousness',
    'malign',
    'malignance',
    'malignancies',
    'malignancy',
    'malignant',
    'maligner',
    'malignity',
    'malignment',
    'malik',
    'malinger',
    'malingerer',
    'malingering',
    'malinois',
    'malinowski',
    'mall',
    'mallard',
    'mallards',
    'mallarme',
    'malleability',
    'malleable',
    'mallee',
    'mallet',
    'mallets',
    'malleus',
    'mallon',
    'mallophaga',
    'mallotus',
    'mallow',
    'mallows',
    'malmo',
    'malmsey',
    'malnourish',
    'malnourished',
    'malnourishment',
    'malnutrition',
    'malocclusion',
    'malodor',
    'malodorous',
    'malodorousness',
    'malodour',
    'malodourous',
    'malone',
    'malonylurea',
    'malope',
    'malopterurus',
    'malory',
    'malosma',
    'malpighi',
    'malpighia',
    'malpighiaceae',
    'malpighian',
    'malposed',
    'malposition',
    'malpractice',
    'malraux',
    'mals',
    'malt',
    'malta',
    'malted',
    'maltese',
    'maltha',
    'malthus',
    'malthusian',
    'malthusianism',
    'malti',
    'maltman',
    'malto',
    'maltose',
    'maltreat',
    'maltreated',
    'maltreater',
    'maltreatment',
    'maltster',
    'malus',
    'malva',
    'malvaceae',
    'malvales',
    'malvasia',
    'malvastrum',
    'malvaviscus',
    'malversate',
    'malversation',
    'malware',
    'mam',
    'mama',
    'mamba',
    'mambas',
    'mambo',
    'mamet',
    'mamey',
    'mamilla',
    'mamillary',
    'mamma',
    'mammal',
    'mammalia',
    'mammalian',
    'mammalogist',
    'mammalogy',
    'mammals',
    'mammary',
    'mammea',
    'mammee',
    'mammilla',
    'mammillaria',
    'mammogram',
    'mammography',
    'mammon',
    'mammoth',
    'mammothermography',
    'mammoths',
    'mammut',
    'mammuthus',
    'mammutidae',
    'mammy',
    'mamo',
    'mamoncillo',
    'man',
    'manacle',
    'manacles',
    'manage',
    'manageability',
    'manageable',
    'manageableness',
    'managed',
    'management',
    'managements',
    'manager',
    'manageress',
    'managerial',
    'managers',
    'managership',
    'manages',
    'managing',
    'managua',
    'manakin',
    'manakins',
    'manama',
    'manana',
    'manannan',
    'manat',
    'manatee',
    'manatees',
    'manawydan',
    'manawyddan',
    'manchester',
    'manchu',
    'manchuria',
    'manchurian',
    'mancunian',
    'manda',
    'mandaean',
    'mandaeanism',
    'mandala',
    'mandalay',
    'mandamus',
    'mandara',
    'mandarin',
    'mandarins',
    'mandatary',
    'mandate',
    'mandated',
    'mandates',
    'mandator',
    'mandatory',
    'mande',
    'mandean',
    'mandeanism',
    'mandeans',
    'mandela',
    'mandelamine',
    'mandelbrot',
    'mandelshtam',
    'mandelstam',
    'mandevilla',
    'mandible',
    'mandibles',
    'mandibula',
    'mandibular',
    'mandibulate',
    'mandibulofacial',
    'mandioc',
    'mandioca',
    'mandola',
    'mandolin',
    'mandragora',
    'mandrake',
    'mandrel',
    'mandril',
    'mandrill',
    'mandrillus',
    'manduca',
    'manducate',
    'manduction',
    'mane',
    'manes',
    'manet',
    'maneuver',
    'maneuverability',
    'maneuverable',
    'maneuvered',
    'maneuverer',
    'maneuvering',
    'maneuvers',
    'manful',
    'manfulness',
    'manga',
    'mangabey',
    'mangabeys',
    'manganate',
    'manganese',
    'manganic',
    'manganite',
    'mange',
    'manger',
    'mangey',
    'mangifera',
    'manginess',
    'mangle',
    'mangled',
    'mangler',
    'manglietia',
    'mango',
    'mangold',
    'mangonel',
    'mangosteen',
    'mangosteens',
    'mangrove',
    'mangroves',
    'mangy',
    'manhandle',
    'manhandled',
    'manhattan',
    'manhole',
    'manhood',
    'manhunt',
    'mania',
    'maniac',
    'maniacal',
    'manic',
    'manichaean',
    'manichaeanism',
    'manichaeism',
    'manichean',
    'manichee',
    'maniclike',
    'manicotti',
    'manicure',
    'manicurist',
    'manidae',
    'manifest',
    'manifestation',
    'manifestations',
    'manifested',
    'manifesting',
    'manifestly',
    'manifesto',
    'manifests',
    'manifold',
    'manihot',
    'manikin',
    'manila',
    'manilkara',
    'manilla',
    'manioc',
    'manioca',
    'manipulability',
    'manipulable',
    'manipulate',
    'manipulated',
    'manipulates',
    'manipulating',
    'manipulation',
    'manipulative',
    'manipulator',
    'manipur',
    'maniraptor',
    'maniraptora',
    'manis',
    'manitoba',
    'mankato',
    'mankind',
    'manky',
    'manlike',
    'manliness',
    'manly',
    'mann',
    'manna',
    'manned',
    'mannequin',
    'manner',
    'mannered',
    'mannerism',
    'mannerisms',
    'mannerly',
    'manners',
    'mannheim',
    'mannikin',
    'manning',
    'mannish',
    'mannitol',
    'manoeuver',
    'manoeuvrability',
    'manoeuvrable',
    'manoeuvre',
    'manoeuvrer',
    'manometer',
    'manor',
    'manorial',
    'manpad',
    'manpower',
    'manque',
    'manroot',
    'mansa',
    'mansard',
    'mansart',
    'manse',
    'manservant',
    'mansfield',
    'mansi',
    'mansion',
    'manslaughter',
    'manslayer',
    'manson',
    'manta',
    'mantas',
    'mantegna',
    'manteidae',
    'mantel',
    'mantelet',
    'mantell',
    'mantelpiece',
    'manteodea',
    'mantic',
    'mantichora',
    'manticora',
    'manticore',
    'mantid',
    'mantidae',
    'mantids',
    'mantiger',
    'mantilla',
    'mantinea',
    'mantineia',
    'mantis',
    'mantises',
    'mantispid',
    'mantispidae',
    'mantispids',
    'mantissa',
    'mantle',
    'mantled',
    'mantlepiece',
    'mantles',
    'mantlet',
    'mantophasmatodea',
    'mantra',
    'mantrap',
    'mantras',
    'mantua',
    'manual',
    'manually',
    'manuals',
    'manubrium',
    'manufactory',
    'manufacture',
    'manufactured',
    'manufacturer',
    'manufacturers',
    'manufactures',
    'manufacturing',
    'manul',
    'manumission',
    'manumit',
    'manumitter',
    'manure',
    'manus',
    'manuscript',
    'manuscripts',
    'manx',
    'many',
    'manzanilla',
    'manzanita',
    'manzoni',
    'mao',
    'maoi',
    'maois',
    'maoism',
    'maoist',
    'maori',
    'maoris',
    'map',
    'mapinguari',
    'maple',
    'maplelike',
    'maples',
    'mapmaking',
    'mapped',
    'mapper',
    'mapping',
    'mapquest',
    'maps',
    'maputo',
    'maquiladora',
    'maquis',
    'maquisard',
    'mar',
    'mara',
    'marabou',
    'marabous',
    'marabout',
    'maraca',
    'maracaibo',
    'maracay',
    'maraco',
    'marang',
    'maranta',
    'marantaceae',
    'maras',
    'marasca',
    'maraschino',
    'marasmius',
    'marasmus',
    'marat',
    'maratha',
    'marathi',
    'marathon',
    'marathoner',
    'marattia',
    'marattiaceae',
    'marattiales',
    'maraud',
    'marauder',
    'marauding',
    'maravilla',
    'marble',
    'marbled',
    'marbleisation',
    'marbleise',
    'marbleised',
    'marbleising',
    'marbleization',
    'marbleize',
    'marbleized',
    'marbleizing',
    'marbles',
    'marblewood',
    'marbling',
    'marbre',
    'marburg',
    'marc',
    'marceau',
    'marcel',
    'march',
    'marchantia',
    'marchantiaceae',
    'marchantiales',
    'marche',
    'marched',
    'marcher',
    'marches',
    'marching',
    'marchioness',
    'marchland',
    'marchpane',
    'marciano',
    'marcionism',
    'marco',
    'marconi',
    'marcus',
    'marcuse',
    'mardi',
    'marduk',
    'mare',
    'marengo',
    'mares',
    'margaret',
    'margaric',
    'margarin',
    'margarine',
    'margarita',
    'margasivsa',
    'margate',
    'margay',
    'marge',
    'margin',
    'marginal',
    'marginalia',
    'marginalisation',
    'marginalise',
    'marginality',
    'marginalization',
    'marginalize',
    'marginally',
    'marginocephalia',
    'marginocephalian',
    'margins',
    'margosa',
    'margot',
    'margrave',
    'marguerite',
    'mari',
    'maria',
    'mariachi',
    'marian',
    'mariana',
    'marianas',
    'maricopa',
    'marie',
    'mariehamn',
    'marigold',
    'marigolds',
    'marihuana',
    'marijuana',
    'marimba',
    'marina',
    'marinade',
    'marinara',
    'marinate',
    'marinated',
    'marinating',
    'marine',
    'marineland',
    'mariner',
    'mariners',
    'marines',
    'marinese',
    'marini',
    'marino',
    'mario',
    'marionette',
    'marionettes',
    'mariposa',
    'mariposan',
    'maris',
    'marital',
    'mariticide',
    'maritime',
    'maritimes',
    'marjoram',
    'mark',
    'marked',
    'markedly',
    'marker',
    'markers',
    'market',
    'marketable',
    'marketed',
    'marketer',
    'marketing',
    'marketplace',
    'markets',
    'markhoor',
    'markhor',
    'marking',
    'markings',
    'markka',
    'markoff',
    'markov',
    'markova',
    'markovian',
    'marks',
    'marksman',
    'marksmanship',
    'markup',
    'markweed',
    'marl',
    'marlberry',
    'marlborough',
    'marlene',
    'marley',
    'marlin',
    'marline',
    'marlinespike',
    'marlingspike',
    'marlins',
    'marlinspike',
    'marlite',
    'marlowe',
    'marlstone',
    'marly',
    'marmalade',
    'marmara',
    'marmite',
    'marmon',
    'marmora',
    'marmoreal',
    'marmorean',
    'marmoset',
    'marmosets',
    'marmot',
    'marmota',
    'marmots',
    'maroc',
    'marocain',
    'maroon',
    'marooned',
    'marplan',
    'marquand',
    'marque',
    'marquee',
    'marquess',
    'marqueterie',
    'marquetry',
    'marquette',
    'marquis',
    'marquise',
    'marrakech',
    'marrakesh',
    'marrano',
    'marred',
    'marri',
    'marriage',
    'marriageability',
    'marriageable',
    'marriages',
    'married',
    'marries',
    'marrow',
    'marrowbone',
    'marrowbones',
    'marrowfat',
    'marrowlike',
    'marrubium',
    'marruecos',
    'marry',
    'marrying',
    'mars',
    'marsala',
    'marseillaise',
    'marseille',
    'marseilles',
    'marsh',
    'marshal',
    'marshaling',
    'marshall',
    'marshals',
    'marshalship',
    'marshes',
    'marshland',
    'marshlands',
    'marshmallow',
    'marshy',
    'marsilea',
    'marsileaceae',
    'marstan',
    'marsupial',
    'marsupialia',
    'marsupials',
    'marsupium',
    'mart',
    'martaban',
    'martagon',
    'marten',
    'martens',
    'martensite',
    'martes',
    'marti',
    'martial',
    'martian',
    'martin',
    'martinet',
    'martingale',
    'martini',
    'martinique',
    'martinis',
    'martinmas',
    'martins',
    'martynia',
    'martyniaceae',
    'martyr',
    'martyrdom',
    'martyred',
    'martyrise',
    'martyrize',
    'martyrs',
    'marum',
    'marumi',
    'marupa',
    'marut',
    'marvel',
    'marveled',
    'marvell',
    'marvelled',
    'marveller',
    'marvellous',
    'marvelous',
    'marvels',
    'marx',
    'marxism',
    'marxist',
    'mary',
    'maryland',
    'marylander',
    'marzipan',
    'masa',
    'masai',
    'mascara',
    'mascarpone',
    'mascot',
    'masculine',
    'masculinisation',
    'masculinise',
    'masculinity',
    'masculinization',
    'masculinize',
    'masculinized',
    'masdevallia',
    'masefield',
    'maser',
    'masers',
    'maseru',
    'mash',
    'mashed',
    'masher',
    'mashhad',
    'mashi',
    'mashie',
    'mashing',
    'mashriq',
    'masjid',
    'mask',
    'masked',
    'masker',
    'masking',
    'masks',
    'masochism',
    'masochist',
    'masochistic',
    'mason',
    'masonic',
    'masonite',
    'masonry',
    'masons',
    'masora',
    'masorah',
    'masorete',
    'masoretic',
    'masorite',
    'masoud',
    'masqat',
    'masque',
    'masquer',
    'masquerade',
    'masquerader',
    'masquerading',
    'mass',
    'massachuset',
    'massachusetts',
    'massacre',
    'massacred',
    'massage',
    'massaged',
    'massager',
    'massasauga',
    'massasoit',
    'massawa',
    'masse',
    'massed',
    'massenet',
    'masses',
    'masseter',
    'masseur',
    'masseuse',
    'massicot',
    'massicotite',
    'massif',
    'massine',
    'massing',
    'massive',
    'massively',
    'massiveness',
    'massorete',
    'mast',
    'mastaba',
    'mastabah',
    'mastalgia',
    'mastectomy',
    'masted',
    'master',
    'mastered',
    'masterful',
    'mastering',
    'masterless',
    'masterly',
    'mastermind',
    'masterminded',
    'masterpiece',
    'masters',
    'mastership',
    'masterstroke',
    'masterworks',
    'masterwort',
    'mastery',
    'masthead',
    'mastic',
    'masticate',
    'masticating',
    'mastication',
    'masticophis',
    'mastiff',
    'mastigomycota',
    'mastigomycotina',
    'mastigophora',
    'mastigophoran',
    'mastigophore',
    'mastigoproctus',
    'mastitis',
    'mastocyte',
    'mastodon',
    'mastodons',
    'mastodont',
    'mastoid',
    'mastoidal',
    'mastoidale',
    'mastoidectomy',
    'mastoiditis',
    'mastopathy',
    'mastopexy',
    'mastotermes',
    'mastotermitidae',
    'masts',
    'masturbate',
    'masturbated',
    'masturbates',
    'masturbation',
    'masturbator',
    'mat',
    'matabele',
    'matador',
    'matai',
    'matakam',
    'matamoros',
    'match',
    'matchboard',
    'matchboards',
    'matchbook',
    'matchbox',
    'matchbush',
    'matched',
    'matcher',
    'matches',
    'matchet',
    'matching',
    'matchless',
    'matchlock',
    'matchmaker',
    'matchmaking',
    'matchstick',
    'matchsticks',
    'matchup',
    'matchweed',
    'matchwood',
    'mate',
    'mated',
    'mateless',
    'matelote',
    'mater',
    'materfamilias',
    'material',
    'materialisation',
    'materialise',
    'materialism',
    'materialist',
    'materialistic',
    'materiality',
    'materialization',
    'materialize',
    'materially',
    'materials',
    'materiel',
    'maternal',
    'maternalism',
    'maternalistic',
    'maternity',
    'mates',
    'matey',
    'math',
    'mathematical',
    'mathematically',
    'mathematician',
    'mathematicians',
    'mathematics',
    'mathias',
    'maths',
    'matilija',
    'matinee',
    'mating',
    'matins',
    'matisse',
    'matman',
    'matoaka',
    'matriarch',
    'matriarchal',
    'matriarchate',
    'matriarchic',
    'matriarchy',
    'matric',
    'matricaria',
    'matricentric',
    'matrices',
    'matricide',
    'matriculate',
    'matriculation',
    'matrikin',
    'matrilineage',
    'matrilineal',
    'matrilinear',
    'matrimonial',
    'matrimony',
    'matrisib',
    'matrix',
    'matron',
    'matronly',
    'matronymic',
    'mats',
    'matsyendra',
    'matt',
    'matte',
    'matted',
    'matter',
    'matterhorn',
    'mattering',
    'matters',
    'matteuccia',
    'matthew',
    'matthias',
    'matthiola',
    'matting',
    'mattock',
    'mattole',
    'mattress',
    'mattresses',
    'maturate',
    'maturation',
    'maturational',
    'mature',
    'matured',
    'maturement',
    'matureness',
    'matures',
    'maturing',
    'maturities',
    'maturity',
    'matutinal',
    'matzah',
    'matzo',
    'matzoh',
    'matzos',
    'maud',
    'maudlin',
    'maugham',
    'maui',
    'maul',
    'mauldin',
    'mauler',
    'maulers',
    'maulstick',
    'maund',
    'maunder',
    'maundy',
    'maupassant',
    'mauriac',
    'maurice',
    'maurier',
    'mauritania',
    'mauritanian',
    'mauritanie',
    'mauritian',
    'mauritius',
    'maurois',
    'mauser',
    'mausoleum',
    'mauve',
    'maven',
    'maverick',
    'mavik',
    'mavin',
    'mavis',
    'maw',
    'mawkish',
    'mawkishness',
    'mawlamyine',
    'max',
    'maxed',
    'maxi',
    'maxilla',
    'maxillae',
    'maxillaria',
    'maxillary',
    'maxillodental',
    'maxillofacial',
    'maxillomandibular',
    'maxim',
    'maxima',
    'maximal',
    'maximally',
    'maximation',
    'maximian',
    'maximisation',
    'maximise',
    'maximising',
    'maximization',
    'maximize',
    'maximized',
    'maximizing',
    'maxims',
    'maximum',
    'maxostoma',
    'maxwell',
    'maxwells',
    'maxzide',
    'may',
    'maya',
    'mayaca',
    'mayacaceae',
    'mayakovski',
    'mayan',
    'mayans',
    'mayapple',
    'mayas',
    'mayday',
    'mayeng',
    'mayenne',
    'mayer',
    'mayetiola',
    'mayfish',
    'mayflies',
    'mayflower',
    'mayfly',
    'mayhaw',
    'mayhem',
    'mayidism',
    'maynard',
    'mayo',
    'mayonnaise',
    'mayor',
    'mayoral',
    'mayoralty',
    'mayoress',
    'maypole',
    'maypop',
    'mays',
    'mayweed',
    'mazama',
    'mazatlan',
    'mazda',
    'mazdaism',
    'maze',
    'mazed',
    'mazer',
    'mazopathy',
    'mazurka',
    'mazy',
    'mazzard',
    'mazzini',
    'mb',
    'mba',
    'mbabane',
    'mbd',
    'mbeya',
    'mbit',
    'mbundu',
    'mc',
    'mcalester',
    'mcallen',
    'mccarten',
    'mccarthy',
    'mccarthyism',
    'mccartney',
    'mccauley',
    'mccormick',
    'mccullers',
    'mcg',
    'mcgraw',
    'mcguffey',
    'mcguffin',
    'mcia',
    'mcintosh',
    'mckim',
    'mckinley',
    'mcluhan',
    'mcmaster',
    'mcpherson',
    'md',
    'mdi',
    'mdiv',
    'mdma',
    'me',
    'mea',
    'mead',
    'meade',
    'meadow',
    'meadowgrass',
    'meadowlark',
    'meadowlarks',
    'meadows',
    'meager',
    'meagerly',
    'meagerness',
    'meagre',
    'meagreness',
    'meal',
    'mealberry',
    'mealie',
    'meals',
    'mealtime',
    'mealworm',
    'mealworms',
    'mealy',
    'mealybug',
    'mealybugs',
    'mealymouthed',
    'mean',
    'meander',
    'meanders',
    'meaner',
    'meanie',
    'meaning',
    'meaningful',
    'meaningfulness',
    'meaningless',
    'meaninglessness',
    'meanings',
    'meanly',
    'meanness',
    'means',
    'meanspirited',
    'meant',
    'meantime',
    'meanwhile',
    'meany',
    'mearstone',
    'measles',
    'measly',
    'measurability',
    'measurable',
    'measure',
    'measured',
    'measureless',
    'measurement',
    'measurements',
    'measurer',
    'measures',
    'measuring',
    'measurings',
    'meat',
    'meatball',
    'meatballs',
    'meatless',
    'meatloaf',
    'meatman',
    'meatpacking',
    'meats',
    'meatus',
    'meatuses',
    'meaty',
    'mebaral',
    'mebendazole',
    'mebibit',
    'mebibits',
    'mebibyte',
    'mebibytes',
    'mecca',
    'meccano',
    'mechanic',
    'mechanical',
    'mechanically',
    'mechanics',
    'mechanisation',
    'mechanise',
    'mechanised',
    'mechanism',
    'mechanisms',
    'mechanist',
    'mechanistic',
    'mechanization',
    'mechanize',
    'mechanized',
    'mecholyl',
    'meclizine',
    'meclofenamate',
    'meclomen',
    'meconium',
    'meconopsis',
    'mecoptera',
    'mecopteran',
    'mecopterans',
    'mecopterous',
    'med',
    'medal',
    'medalist',
    'medallion',
    'medallist',
    'medals',
    'medan',
    'medawar',
    'meddle',
    'meddler',
    'meddles',
    'meddlesome',
    'meddlesomeness',
    'meddling',
    'medea',
    'medellin',
    'medevac',
    'medfly',
    'medford',
    'media',
    'mediacy',
    'mediaeval',
    'medial',
    'medially',
    'median',
    'mediant',
    'mediastinum',
    'mediate',
    'mediated',
    'mediateness',
    'mediates',
    'mediating',
    'mediation',
    'mediator',
    'mediatorial',
    'mediators',
    'mediatory',
    'mediatrix',
    'medic',
    'medicago',
    'medicaid',
    'medical',
    'medically',
    'medicament',
    'medicare',
    'medicate',
    'medicated',
    'medication',
    'medications',
    'medicative',
    'medici',
    'medicinal',
    'medicinally',
    'medicine',
    'medicines',
    'medicis',
    'medick',
    'medico',
    'medicolegal',
    'mediety',
    'medieval',
    'medina',
    'medinilla',
    'mediocre',
    'mediocrities',
    'mediocrity',
    'meditate',
    'meditating',
    'meditation',
    'meditative',
    'meditativeness',
    'mediterranean',
    'medium',
    'medivac',
    'medlar',
    'medlars',
    'medley',
    'medline',
    'medoc',
    'medroxyprogesterone',
    'medulla',
    'medullary',
    'medullated',
    'medusa',
    'medusan',
    'medusoid',
    'meed',
    'meek',
    'meekness',
    'meerestone',
    'meerkat',
    'meerkats',
    'meerschaum',
    'meet',
    'meeter',
    'meeting',
    'meetinghouse',
    'meetings',
    'meets',
    'mefloquine',
    'mefoxin',
    'meg',
    'megabat',
    'megabit',
    'megabits',
    'megabucks',
    'megabyte',
    'megabytes',
    'megacardia',
    'megacephaly',
    'megachile',
    'megachilidae',
    'megachiroptera',
    'megacolon',
    'megacycle',
    'megadeath',
    'megaderma',
    'megadermatidae',
    'megaera',
    'megaflop',
    'megagametophyte',
    'megahertz',
    'megahit',
    'megakaryocyte',
    'megakaryocytic',
    'megalith',
    'megalithic',
    'megaliths',
    'megalobatrachus',
    'megaloblast',
    'megaloblastic',
    'megaloblasts',
    'megalocardia',
    'megalocephaly',
    'megalocyte',
    'megalohepatia',
    'megalomania',
    'megalomaniac',
    'megalomaniacal',
    'megalomanic',
    'megalonychidae',
    'megalopolis',
    'megaloptera',
    'megalosaur',
    'megalosauridae',
    'megalosaurs',
    'megalosaurus',
    'megaphone',
    'megapode',
    'megapodes',
    'megapodiidae',
    'megapodius',
    'megaptera',
    'megascopic',
    'megasporangia',
    'megasporangium',
    'megaspore',
    'megaspores',
    'megasporophyll',
    'megathere',
    'megatherian',
    'megatheriid',
    'megatheriidae',
    'megatherium',
    'megaton',
    'megawatt',
    'megestrol',
    'megillah',
    'megilp',
    'megohm',
    'megrim',
    'megrims',
    'mei',
    'meibomian',
    'meiosis',
    'meiotic',
    'meir',
    'meissner',
    'meitner',
    'meitnerium',
    'mek',
    'mekong',
    'melaena',
    'melagra',
    'melamine',
    'melampodium',
    'melampsora',
    'melampsoraceae',
    'melancholia',
    'melancholiac',
    'melancholic',
    'melancholy',
    'melanchthon',
    'melanerpes',
    'melanesia',
    'melanesian',
    'melange',
    'melanin',
    'melanise',
    'melanism',
    'melanitta',
    'melanize',
    'melanoblast',
    'melanocyte',
    'melanocytes',
    'melanoderma',
    'melanogrammus',
    'melanoma',
    'melanoplus',
    'melanosis',
    'melanotis',
    'melanthiaceae',
    'melasma',
    'melastoma',
    'melastomaceae',
    'melastomataceae',
    'melatonin',
    'melba',
    'melbourne',
    'melchior',
    'melchite',
    'meld',
    'melded',
    'meleagrididae',
    'meleagris',
    'melee',
    'melena',
    'meles',
    'melia',
    'meliaceae',
    'melicocca',
    'melicoccus',
    'melicytus',
    'melilot',
    'melilotus',
    'melinae',
    'meliorate',
    'melioration',
    'meliorative',
    'meliorism',
    'meliorist',
    'meliphagidae',
    'melissa',
    'melkite',
    'mellaril',
    'mellifluous',
    'mellisonant',
    'mellitus',
    'mellivora',
    'mellon',
    'mellow',
    'mellowed',
    'mellowing',
    'mellowness',
    'melocactus',
    'melodic',
    'melodically',
    'melodies',
    'melodious',
    'melodiousness',
    'melodise',
    'melodize',
    'melodrama',
    'melodramatic',
    'melody',
    'melogale',
    'meloid',
    'meloidae',
    'melolontha',
    'melolonthidae',
    'melon',
    'melons',
    'melophagus',
    'melopsittacus',
    'melosa',
    'melospiza',
    'melphalan',
    'melpomene',
    'melt',
    'meltable',
    'meltdown',
    'melted',
    'melter',
    'melting',
    'melts',
    'meltwater',
    'melursus',
    'melville',
    'mem',
    'member',
    'membered',
    'memberless',
    'members',
    'membership',
    'membracidae',
    'membrane',
    'membranes',
    'membranophone',
    'membranous',
    'meme',
    'memel',
    'memento',
    'memo',
    'memoir',
    'memorabilia',
    'memorability',
    'memorable',
    'memorably',
    'memoranda',
    'memorandum',
    'memorial',
    'memorialisation',
    'memorialise',
    'memorialization',
    'memorialize',
    'memorialized',
    'memories',
    'memorisation',
    'memorise',
    'memoriser',
    'memorization',
    'memorize',
    'memorized',
    'memorizer',
    'memorizes',
    'memorizing',
    'memory',
    'memphis',
    'memsahib',
    'men',
    'menace',
    'menaced',
    'menachem',
    'menacing',
    'menadione',
    'menage',
    'menagerie',
    'menai',
    'menander',
    'menarche',
    'mencken',
    'mend',
    'mendacious',
    'mendacity',
    'mended',
    'mendel',
    'mendeleev',
    'mendelevium',
    'mendeleyev',
    'mendelian',
    'mendelianism',
    'mendelism',
    'mendelsohn',
    'mendelssohn',
    'mendenhall',
    'mender',
    'mendicancy',
    'mendicant',
    'mendicity',
    'mending',
    'mends',
    'menelaus',
    'menhaden',
    'menhir',
    'menial',
    'meniere',
    'meningeal',
    'meninges',
    'meningioma',
    'meningism',
    'meningitis',
    'meningocele',
    'meningoencephalitis',
    'meninx',
    'menippe',
    'meniscectomy',
    'meniscium',
    'meniscus',
    'menispermaceae',
    'menispermum',
    'menninger',
    'mennonite',
    'mennonites',
    'mennonitism',
    'menominee',
    'menomini',
    'menopausal',
    'menopause',
    'menopon',
    'menorah',
    'menorrhagia',
    'menorrhea',
    'menotti',
    'menotyphla',
    'mensa',
    'mensal',
    'mensch',
    'menservants',
    'menses',
    'mensh',
    'menshevik',
    'menstrual',
    'menstruate',
    'menstruated',
    'menstruating',
    'menstruation',
    'menstruum',
    'mensurable',
    'mensural',
    'mensurate',
    'mensuration',
    'mental',
    'mentalism',
    'mentality',
    'mentally',
    'mentation',
    'mentha',
    'menthe',
    'menthol',
    'mentholated',
    'menticirrhus',
    'mention',
    'mentioned',
    'mentioner',
    'mentioning',
    'mentor',
    'mentored',
    'mentum',
    'mentzelia',
    'menu',
    'menuhin',
    'menura',
    'menurae',
    'menuridae',
    'menyanthaceae',
    'menyanthes',
    'menziesia',
    'meow',
    'mepacrine',
    'meperidine',
    'mephaquine',
    'mephenytoin',
    'mephistophelean',
    'mephistopheles',
    'mephistophelian',
    'mephitic',
    'mephitinae',
    'mephitis',
    'mephobarbital',
    'meprin',
    'meprobamate',
    'meq',
    'meralgia',
    'merbromine',
    'mercantile',
    'mercantilism',
    'mercaptopurine',
    'mercator',
    'mercedario',
    'mercedes',
    'mercenaria',
    'mercenary',
    'mercer',
    'mercerise',
    'mercerised',
    'mercerize',
    'mercerized',
    'mercerizing',
    'merchandise',
    'merchandiser',
    'merchandising',
    'merchant',
    'merchantability',
    'merchantable',
    'merchantman',
    'merchants',
    'merciful',
    'mercifulness',
    'merciless',
    'mercilessly',
    'mercilessness',
    'merckx',
    'mercouri',
    'mercurial',
    'mercurialis',
    'mercuric',
    'mercurochrome',
    'mercurous',
    'mercury',
    'mercy',
    'mere',
    'meredith',
    'merely',
    'merestone',
    'meretricious',
    'meretriciousness',
    'merganser',
    'mergansers',
    'merge',
    'merged',
    'mergenthaler',
    'merger',
    'merginae',
    'merging',
    'mergus',
    'mericarp',
    'merida',
    'meridian',
    'meridians',
    'meridional',
    'meringue',
    'merino',
    'meriones',
    'meristem',
    'merit',
    'meritable',
    'merited',
    'meriting',
    'meritless',
    'meritocracy',
    'meritocratic',
    'meritorious',
    'meritoriousness',
    'merits',
    'meriwether',
    'merl',
    'merlangus',
    'merle',
    'merlin',
    'merlon',
    'merlons',
    'merlot',
    'merluccius',
    'mermaid',
    'merman',
    'merodach',
    'meromelia',
    'meronym',
    'meronyms',
    'meronymy',
    'meropidae',
    'merops',
    'merostomata',
    'merovingian',
    'merozoite',
    'merrimac',
    'merrimack',
    'merriment',
    'merriness',
    'merry',
    'merrymaker',
    'merrymaking',
    'mertensia',
    'merthiolate',
    'merton',
    'merven',
    'meryta',
    'mesa',
    'mesabi',
    'mesalliance',
    'mesantoin',
    'mesasamkranti',
    'mescal',
    'mescaline',
    'mesembryanthemum',
    'mesencephalon',
    'mesenchyme',
    'mesenteric',
    'mesentery',
    'mesh',
    'meshed',
    'meshes',
    'meshing',
    'meshuga',
    'meshugaas',
    'meshugga',
    'meshugge',
    'meshuggeneh',
    'meshuggener',
    'meshwork',
    'mesial',
    'mesic',
    'mesmer',
    'mesmeric',
    'mesmerise',
    'mesmerised',
    'mesmerising',
    'mesmerism',
    'mesmerist',
    'mesmerize',
    'mesmerized',
    'mesmerizer',
    'mesmerizing',
    'mesoamerica',
    'mesoamerican',
    'mesoamericans',
    'mesoblast',
    'mesoblastic',
    'mesocarp',
    'mesocolon',
    'mesocricetus',
    'mesoderm',
    'mesodermal',
    'mesohippus',
    'mesolithic',
    'mesomorph',
    'mesomorphic',
    'mesomorphy',
    'meson',
    'mesonic',
    'mesons',
    'mesophyron',
    'mesophyte',
    'mesophytic',
    'mesopotamia',
    'mesosphere',
    'mesothelioma',
    'mesothelium',
    'mesotron',
    'mesozoic',
    'mespilus',
    'mesquit',
    'mesquite',
    'mess',
    'message',
    'messaged',
    'messages',
    'messaging',
    'messed',
    'messenger',
    'messiah',
    'messiahship',
    'messianic',
    'messidor',
    'messina',
    'messiness',
    'messmate',
    'messuage',
    'messy',
    'mestiza',
    'mestizo',
    'mestranol',
    'mesua',
    'met',
    'metabola',
    'metabolic',
    'metabolically',
    'metabolise',
    'metabolism',
    'metabolite',
    'metabolize',
    'metabolized',
    'metabolous',
    'metacarpal',
    'metacarpals',
    'metacarpus',
    'metacenter',
    'metacentre',
    'metacentric',
    'metacyesis',
    'metadata',
    'metagenesis',
    'metagrabolised',
    'metagrabolized',
    'metagrobolised',
    'metagrobolized',
    'metaknowledge',
    'metal',
    'metalanguage',
    'metalepsis',
    'metalhead',
    'metalize',
    'metallic',
    'metallike',
    'metallize',
    'metalloid',
    'metallurgic',
    'metallurgical',
    'metallurgist',
    'metallurgy',
    'metals',
    'metalware',
    'metalwork',
    'metalworker',
    'metalworking',
    'metalworks',
    'metamathematics',
    'metamere',
    'metameres',
    'metameric',
    'metamorphic',
    'metamorphism',
    'metamorphopsia',
    'metamorphose',
    'metamorphosed',
    'metamorphoses',
    'metamorphosing',
    'metamorphosis',
    'metamorphous',
    'metaphase',
    'metaphor',
    'metaphoric',
    'metaphorical',
    'metaphorically',
    'metaphors',
    'metaphysical',
    'metaphysics',
    'metaphysis',
    'metaproterenol',
    'metarule',
    'metasequoia',
    'metastability',
    'metastable',
    'metastasis',
    'metastasise',
    'metastasize',
    'metastasized',
    'metastasizes',
    'metastatic',
    'metatarsal',
    'metatarsals',
    'metatarsus',
    'metatheria',
    'metatherian',
    'metathesis',
    'metaurus',
    'metazoa',
    'metazoan',
    'metazoans',
    'metchnikoff',
    'metchnikov',
    'mete',
    'metempsychosis',
    'metencephalon',
    'meteor',
    'meteoric',
    'meteorite',
    'meteorites',
    'meteoritic',
    'meteoritical',
    'meteoroid',
    'meteoroids',
    'meteorologic',
    'meteorological',
    'meteorologist',
    'meteorologists',
    'meteorology',
    'meteors',
    'meteortropism',
    'meter',
    'meters',
    'meterstick',
    'metformin',
    'meth',
    'methacholine',
    'methadon',
    'methadone',
    'methamphetamine',
    'methanal',
    'methane',
    'methanogen',
    'methanol',
    'methapyrilene',
    'methaqualone',
    'metharbital',
    'methedrine',
    'metheglin',
    'methenamine',
    'methicillin',
    'methionine',
    'methocarbamol',
    'method',
    'methodical',
    'methodicalness',
    'methodism',
    'methodist',
    'methodists',
    'methodological',
    'methodologically',
    'methodology',
    'methods',
    'methotrexate',
    'methuselah',
    'methyl',
    'methylated',
    'methylbenzene',
    'methyldopa',
    'methylene',
    'methylenedioxymethamphetamine',
    'methylphenidate',
    'methyltestosterone',
    'metic',
    'metical',
    'meticorten',
    'meticulosity',
    'meticulous',
    'meticulously',
    'meticulousness',
    'metier',
    'meting',
    'metis',
    'metonym',
    'metonymic',
    'metonymical',
    'metonymy',
    'metopion',
    'metoprolol',
    'metralgia',
    'metrazol',
    'metre',
    'metrestick',
    'metric',
    'metrical',
    'metrically',
    'metricate',
    'metrication',
    'metricise',
    'metricize',
    'metrics',
    'metrification',
    'metrified',
    'metrify',
    'metritis',
    'metro',
    'metrological',
    'metrology',
    'metronidazole',
    'metronome',
    'metronymic',
    'metropolis',
    'metropolitan',
    'metroptosis',
    'metrorrhagia',
    'metroxylon',
    'metternich',
    'mettle',
    'mettlesome',
    'mettlesomeness',
    'metycaine',
    'meuse',
    'mevacor',
    'mew',
    'mewing',
    'mewl',
    'mews',
    'mexicali',
    'mexican',
    'mexicano',
    'mexicans',
    'mexico',
    'mexiletine',
    'mexitil',
    'meyer',
    'meyerbeer',
    'meyerhof',
    'mezcal',
    'mezereon',
    'mezereum',
    'mezuza',
    'mezuzah',
    'mezzanine',
    'mezzo',
    'mezzotint',
    'mf',
    'mfa',
    'mflop',
    'mg',
    'mho',
    'mhz',
    'mi',
    'miami',
    'miao',
    'miaou',
    'miaow',
    'miasm',
    'miasma',
    'miasmal',
    'miasmic',
    'miaul',
    'mib',
    'mibit',
    'mic',
    'mica',
    'micaceous',
    'micah',
    'micawber',
    'mice',
    'micelle',
    'michael',
    'michaelmas',
    'michaelmastide',
    'michaels',
    'micheas',
    'michel',
    'michelangelesque',
    'michelangelo',
    'michelson',
    'michener',
    'michigan',
    'michigander',
    'michiko',
    'mick',
    'mickey',
    'mickle',
    'micmac',
    'miconazole',
    'micro',
    'microbalance',
    'microbar',
    'microbat',
    'microbe',
    'microbes',
    'microbial',
    'microbic',
    'microbiologist',
    'microbiology',
    'microbrachia',
    'microbrewery',
    'microcentrum',
    'microcephalic',
    'microcephalous',
    'microcephalus',
    'microcephaly',
    'microchip',
    'microchiroptera',
    'microcircuit',
    'micrococcaceae',
    'micrococcus',
    'microcode',
    'microcomputer',
    'microcomputers',
    'microcopy',
    'microcosm',
    'microcosmic',
    'microcrystalline',
    'microcyte',
    'microcytes',
    'microcytosis',
    'microdesmidae',
    'microdipodops',
    'microdot',
    'microeconomic',
    'microeconomics',
    'microeconomist',
    'microelectronic',
    'microelectronics',
    'microevolution',
    'microfarad',
    'microfiche',
    'microfilm',
    'microflora',
    'microfossil',
    'microfossils',
    'microgametophyte',
    'microgauss',
    'microglia',
    'microgliacyte',
    'microgram',
    'microgramma',
    'microhylidae',
    'micromeria',
    'micrometeor',
    'micrometeoric',
    'micrometeorite',
    'micrometeorites',
    'micrometeoritic',
    'micrometeoroid',
    'micrometer',
    'micrometry',
    'micromicron',
    'micromillimeter',
    'micromillimetre',
    'micromyx',
    'micron',
    'micronase',
    'micronesia',
    'micronor',
    'microns',
    'micronutrient',
    'microorganism',
    'microorganisms',
    'micropaleontology',
    'micropenis',
    'microphage',
    'microphallus',
    'microphone',
    'microphones',
    'microphoning',
    'microphotometer',
    'micropogonias',
    'microprocessor',
    'microprocessors',
    'micropterus',
    'micropylar',
    'micropyle',
    'microradian',
    'microscope',
    'microscopes',
    'microscopic',
    'microscopical',
    'microscopically',
    'microscopist',
    'microscopium',
    'microscopy',
    'microsecond',
    'microseism',
    'microsomal',
    'microsome',
    'microsomes',
    'microsorium',
    'microsporangia',
    'microsporangium',
    'microspore',
    'microspores',
    'microsporidian',
    'microsporophyll',
    'microsporum',
    'microstomus',
    'microstrobos',
    'microsurgery',
    'microtaggant',
    'microtome',
    'microtubule',
    'microtubules',
    'microtus',
    'microvolt',
    'microwave',
    'microwaves',
    'microzide',
    'micruroides',
    'micrurus',
    'micturate',
    'micturition',
    'mid',
    'midafternoon',
    'midair',
    'midas',
    'midazolam',
    'midbrain',
    'midday',
    'midden',
    'middle',
    'middlebreaker',
    'middlebrow',
    'middleman',
    'middlemen',
    'middlemost',
    'middleton',
    'middleweight',
    'middling',
    'middy',
    'mideast',
    'midfield',
    'midfielder',
    'midgard',
    'midge',
    'midges',
    'midget',
    'midgrass',
    'midi',
    'midinette',
    'midiron',
    'midland',
    'midline',
    'midmost',
    'midnight',
    'midplane',
    'midpoint',
    'midrash',
    'midrib',
    'midribs',
    'midriff',
    'midsection',
    'midshipman',
    'midshipmen',
    'midships',
    'midst',
    'midstream',
    'midsummer',
    'midterm',
    'midvein',
    'midwatch',
    'midway',
    'midweek',
    'midweekly',
    'midwest',
    'midwestern',
    'midwife',
    'midwifery',
    'midwinter',
    'mien',
    'mierkat',
    'mifepristone',
    'miff',
    'miffed',
    'might',
    'mightier',
    'mightiness',
    'mighty',
    'mignonette',
    'migraine',
    'migrant',
    'migrate',
    'migrated',
    'migrates',
    'migrating',
    'migration',
    'migrational',
    'migrations',
    'migrator',
    'migratory',
    'mihrab',
    'mikado',
    'mikania',
    'mike',
    'mikmaq',
    'mikvah',
    'mil',
    'milady',
    'milage',
    'milan',
    'milanese',
    'milano',
    'milch',
    'milcher',
    'mild',
    'milder',
    'mildew',
    'mildewed',
    'mildews',
    'mildly',
    'mildness',
    'mile',
    'mileage',
    'mileometer',
    'milepost',
    'miler',
    'miles',
    'milestone',
    'milfoil',
    'milhaud',
    'miliaria',
    'milieu',
    'militainment',
    'militance',
    'militancy',
    'militant',
    'militants',
    'militarisation',
    'militarise',
    'militarised',
    'militarism',
    'militarist',
    'militaristic',
    'militarization',
    'militarize',
    'militarized',
    'militarizing',
    'military',
    'militate',
    'militated',
    'militia',
    'militiaman',
    'milium',
    'milk',
    'milkcap',
    'milked',
    'milker',
    'milking',
    'milkless',
    'milklike',
    'milkmaid',
    'milkman',
    'milkshake',
    'milksop',
    'milkwagon',
    'milkweed',
    'milkwort',
    'milky',
    'mill',
    'millais',
    'millay',
    'millboard',
    'milldam',
    'milled',
    'millenarian',
    'millenarianism',
    'millenarism',
    'millenarist',
    'millenary',
    'millennial',
    'millennian',
    'millennium',
    'millenniumism',
    'millepede',
    'miller',
    'millerite',
    'millet',
    'millettia',
    'milliammeter',
    'milliampere',
    'milliamperes',
    'milliard',
    'millibar',
    'millicurie',
    'millidegree',
    'milliequivalent',
    'millifarad',
    'milligram',
    'milligrams',
    'millihenry',
    'millikan',
    'milliliter',
    'millilitre',
    'millime',
    'millimes',
    'millimeter',
    'millimeters',
    'millimetre',
    'millimicron',
    'milline',
    'milliner',
    'millinery',
    'milling',
    'million',
    'millionaire',
    'millionairess',
    'millions',
    'millionth',
    'milliped',
    'millipede',
    'millipedes',
    'milliradian',
    'millirem',
    'millisecond',
    'millivolt',
    'millivoltmeter',
    'millivolts',
    'milliwatt',
    'millpond',
    'millrace',
    'millrun',
    'mills',
    'millstone',
    'millwheel',
    'millwork',
    'millwright',
    'milne',
    'milo',
    'milometer',
    'milontin',
    'milord',
    'milquetoast',
    'milt',
    'miltiades',
    'miltomate',
    'milton',
    'miltonia',
    'miltown',
    'milvus',
    'milwaukee',
    'mimamsa',
    'mime',
    'mimed',
    'mimeo',
    'mimeograph',
    'mimeographed',
    'mimer',
    'mimesis',
    'mimetic',
    'mimic',
    'mimicked',
    'mimicker',
    'mimicking',
    'mimicry',
    'mimics',
    'mimidae',
    'mimir',
    'mimosa',
    'mimosaceae',
    'mimosoideae',
    'mimus',
    'min',
    'mina',
    'minacious',
    'minah',
    'minamata',
    'minaret',
    'minatory',
    'mince',
    'minced',
    'mincemeat',
    'mincer',
    'mincing',
    'mind',
    'mindanao',
    'minded',
    'minden',
    'minder',
    'mindful',
    'mindfulness',
    'mindless',
    'mindlessness',
    'mindoro',
    'minds',
    'mindset',
    'mine',
    'mined',
    'minefield',
    'minelayer',
    'minelaying',
    'miner',
    'mineral',
    'mineralize',
    'mineralized',
    'mineralocorticoid',
    'mineralogist',
    'mineralogy',
    'minerals',
    'miners',
    'minerva',
    'mines',
    'mineshaft',
    'minestrone',
    'minesweeper',
    'minesweeping',
    'mineworker',
    'ming',
    'minge',
    'minginess',
    'mingle',
    'mingled',
    'mingling',
    'mingy',
    'mini',
    'miniate',
    'miniature',
    'miniaturisation',
    'miniaturise',
    'miniaturist',
    'miniaturization',
    'miniaturize',
    'miniaturized',
    'minibar',
    'minibike',
    'minibus',
    'minicab',
    'minicar',
    'minicomputer',
    'miniconju',
    'minify',
    'minim',
    'minima',
    'minimal',
    'minimalism',
    'minimalist',
    'minimally',
    'minimisation',
    'minimise',
    'minimization',
    'minimize',
    'minimized',
    'minimizes',
    'minimizing',
    'minims',
    'minimum',
    'minimus',
    'mining',
    'minion',
    'minipress',
    'miniscule',
    'miniskirt',
    'minister',
    'ministerial',
    'ministering',
    'ministers',
    'ministrant',
    'ministration',
    'ministries',
    'ministry',
    'minisub',
    'minisubmarine',
    'minium',
    'minivan',
    'miniver',
    'mink',
    'minkowski',
    'minks',
    'minneapolis',
    'minnesota',
    'minnesotan',
    'minnewit',
    'minniebush',
    'minnow',
    'minnows',
    'minoan',
    'minocin',
    'minocycline',
    'minor',
    'minora',
    'minored',
    'minorities',
    'minority',
    'minors',
    'minos',
    'minotaur',
    'minoxidil',
    'minsk',
    'minster',
    'minstrel',
    'minstrels',
    'minstrelsy',
    'mint',
    'mintage',
    'minted',
    'minter',
    'minting',
    'mintmark',
    'mints',
    'minty',
    'minuartia',
    'minuend',
    'minuet',
    'minuit',
    'minus',
    'minuscular',
    'minuscule',
    'minute',
    'minutely',
    'minuteman',
    'minuteness',
    'minutes',
    'minutia',
    'minutiae',
    'minx',
    'minyan',
    'miocene',
    'miosis',
    'miotic',
    'mips',
    'mirabeau',
    'mirabilis',
    'miracle',
    'miracles',
    'miraculous',
    'mirage',
    'mirasol',
    'mire',
    'mired',
    'miri',
    'mirid',
    'miridae',
    'mirish',
    'mirky',
    'miro',
    'miror',
    'mirounga',
    'mirror',
    'mirrored',
    'mirrorlike',
    'mirrors',
    'mirth',
    'mirthful',
    'mirthfulness',
    'mirthless',
    'miry',
    'misaddress',
    'misadventure',
    'misadvise',
    'misalign',
    'misalignment',
    'misalliance',
    'misally',
    'misanthrope',
    'misanthropic',
    'misanthropical',
    'misanthropist',
    'misanthropy',
    'misapplication',
    'misapplied',
    'misapply',
    'misapplying',
    'misapprehend',
    'misapprehension',
    'misappropriate',
    'misappropriated',
    'misappropriation',
    'misbegot',
    'misbegotten',
    'misbehave',
    'misbehaved',
    'misbehaving',
    'misbehavior',
    'misbehaviour',
    'misbelieve',
    'misbeliever',
    'misbranded',
    'miscalculate',
    'miscalculated',
    'miscalculation',
    'miscall',
    'miscarriage',
    'miscarry',
    'miscast',
    'miscegenate',
    'miscegenation',
    'miscellanea',
    'miscellaneous',
    'miscellany',
    'mischance',
    'mischief',
    'mischievous',
    'mischievousness',
    'miscible',
    'misconceive',
    'misconception',
    'misconduct',
    'misconstrual',
    'misconstruction',
    'misconstrue',
    'misconstrued',
    'miscount',
    'miscreant',
    'miscreate',
    'miscreated',
    'miscreation',
    'miscue',
    'misdate',
    'misdating',
    'misdeal',
    'misdeed',
    'misdeeds',
    'misdeliver',
    'misdemean',
    'misdemeanor',
    'misdemeanour',
    'misdirect',
    'misdirected',
    'misdirection',
    'misdo',
    'miser',
    'miserable',
    'miserableness',
    'miseries',
    'miserliness',
    'miserly',
    'misery',
    'misestimate',
    'misestimated',
    'misestimation',
    'misfeasance',
    'misfire',
    'misfit',
    'misfortunate',
    'misfortune',
    'misfortunes',
    'misfunction',
    'misgauge',
    'misgave',
    'misgive',
    'misgiving',
    'misgovern',
    'misgovernment',
    'misguide',
    'misguided',
    'mishandle',
    'mishandling',
    'mishap',
    'mishaps',
    'mishegaas',
    'mishegoss',
    'mishmash',
    'mishna',
    'mishnah',
    'mishnaic',
    'mishpachah',
    'mishpocha',
    'misidentify',
    'misinform',
    'misinformation',
    'misinterpret',
    'misinterpretation',
    'misjudge',
    'mislabeled',
    'mislaid',
    'mislay',
    'mislead',
    'misleader',
    'misleading',
    'misleads',
    'misled',
    'mismanage',
    'mismanagement',
    'mismarry',
    'mismatch',
    'mismatched',
    'mismate',
    'mismated',
    'misname',
    'misnamed',
    'misnomer',
    'miso',
    'misocainea',
    'misogamist',
    'misogamy',
    'misogynic',
    'misogynism',
    'misogynist',
    'misogynistic',
    'misogynous',
    'misogyny',
    'misology',
    'misoneism',
    'misopedia',
    'misperceive',
    'mispickel',
    'misplace',
    'misplaced',
    'misplacement',
    'misplay',
    'misprint',
    'mispronounce',
    'mispronounces',
    'mispronunciation',
    'misquotation',
    'misquote',
    'misquoted',
    'misread',
    'misreading',
    'misreckoning',
    'misrelated',
    'misremember',
    'misremembered',
    'misrepresent',
    'misrepresentation',
    'misrepresented',
    'misrepresenting',
    'misrepresents',
    'misrule',
    'miss',
    'missal',
    'missed',
    'misses',
    'misshapen',
    'misshapenness',
    'missile',
    'missiles',
    'missing',
    'mission',
    'missional',
    'missionaries',
    'missionary',
    'missioner',
    'missions',
    'missis',
    'mississippi',
    'mississippian',
    'missive',
    'missoula',
    'missouri',
    'missourian',
    'misspeak',
    'misspell',
    'misspelled',
    'misspelling',
    'misspellings',
    'misspend',
    'misspent',
    'misstate',
    'misstated',
    'misstatement',
    'misstep',
    'missus',
    'missy',
    'mist',
    'mistakable',
    'mistake',
    'mistaken',
    'mistakenly',
    'mistakes',
    'mistaking',
    'misted',
    'mister',
    'mistflower',
    'mistime',
    'mistimed',
    'mistiming',
    'mistiness',
    'mistletoe',
    'mistook',
    'mistral',
    'mistranslate',
    'mistranslation',
    'mistreat',
    'mistreated',
    'mistreatment',
    'mistress',
    'mistrial',
    'mistrust',
    'mistrustful',
    'mists',
    'misty',
    'misunderstand',
    'misunderstanding',
    'misunderstood',
    'misuse',
    'misused',
    'mit',
    'mitchell',
    'mitchella',
    'mitchum',
    'mite',
    'mitella',
    'miter',
    'miterwort',
    'mites',
    'mitford',
    'mithan',
    'mithra',
    'mithracin',
    'mithraic',
    'mithraicism',
    'mithraism',
    'mithraist',
    'mithraistic',
    'mithramycin',
    'mithras',
    'mithridates',
    'mitigable',
    'mitigate',
    'mitigated',
    'mitigating',
    'mitigation',
    'mitigative',
    'mitigatory',
    'mitochondria',
    'mitochondrion',
    'mitogen',
    'mitomycin',
    'mitosis',
    'mitotic',
    'mitra',
    'mitral',
    'mitre',
    'mitrewort',
    'mitsvah',
    'mitt',
    'mittelschmerz',
    'mitten',
    'mitterrand',
    'mitzvah',
    'miwok',
    'mix',
    'mixable',
    'mixed',
    'mixer',
    'mixes',
    'mixing',
    'mixologist',
    'mixology',
    'mixture',
    'mixtures',
    'mizen',
    'mizenmast',
    'mizzen',
    'mizzenmast',
    'mizzle',
    'mko',
    'ml',
    'mlitt',
    'mls',
    'mm',
    'mmpi',
    'mn',
    'mnemonic',
    'mnemonics',
    'mnemonist',
    'mnemosyne',
    'mnemotechnic',
    'mnemotechnical',
    'mniaceae',
    'mnium',
    'mo',
    'moa',
    'moan',
    'moaned',
    'moaner',
    'moas',
    'moat',
    'moated',
    'mob',
    'moban',
    'mobbish',
    'mobcap',
    'mobile',
    'mobiles',
    'mobilisation',
    'mobilise',
    'mobility',
    'mobilization',
    'mobilize',
    'mobilized',
    'mobilizing',
    'mobius',
    'moblike',
    'mobocracy',
    'mobs',
    'mobster',
    'mobula',
    'mobulidae',
    'mocambique',
    'mocassin',
    'moccasin',
    'mocha',
    'mock',
    'mocked',
    'mocker',
    'mockernut',
    'mockery',
    'mocking',
    'mockingbird',
    'mockingbirds',
    'mockingly',
    'mocks',
    'mod',
    'modal',
    'modalities',
    'modality',
    'mode',
    'model',
    'modeled',
    'modeler',
    'modeling',
    'modelled',
    'modeller',
    'modelling',
    'models',
    'modem',
    'modems',
    'moderate',
    'moderated',
    'moderately',
    'moderateness',
    'moderating',
    'moderation',
    'moderationism',
    'moderationist',
    'moderatism',
    'moderato',
    'moderator',
    'moderatorship',
    'modern',
    'moderne',
    'modernisation',
    'modernise',
    'modernised',
    'modernism',
    'modernist',
    'modernistic',
    'modernity',
    'modernization',
    'modernize',
    'modernized',
    'modernizing',
    'modernness',
    'modes',
    'modest',
    'modestly',
    'modestness',
    'modesty',
    'modicon',
    'modicum',
    'modifiable',
    'modification',
    'modifications',
    'modified',
    'modifier',
    'modifiers',
    'modifies',
    'modify',
    'modifying',
    'modigliani',
    'modillion',
    'modiolus',
    'modish',
    'modishness',
    'modiste',
    'mods',
    'modular',
    'modulate',
    'modulated',
    'modulating',
    'modulation',
    'module',
    'modules',
    'modulo',
    'modulus',
    'moehringia',
    'mogadiscio',
    'mogadishu',
    'moghul',
    'mogul',
    'mohair',
    'mohammad',
    'mohammed',
    'mohammedan',
    'mohammedanism',
    'moharram',
    'mohave',
    'mohawk',
    'mohican',
    'moho',
    'mohorovicic',
    'mohria',
    'mohs',
    'moiety',
    'moil',
    'moiled',
    'moirae',
    'moirai',
    'moire',
    'moist',
    'moisten',
    'moistened',
    'moistener',
    'moistening',
    'moistens',
    'moistness',
    'moisture',
    'moisturise',
    'moisturize',
    'moisturizing',
    'mojarra',
    'mojarras',
    'mojave',
    'mojo',
    'moke',
    'moksa',
    'mokulu',
    'mol',
    'mola',
    'molal',
    'molality',
    'molar',
    'molarity',
    'molars',
    'molasses',
    'mold',
    'moldable',
    'moldavia',
    'moldboard',
    'molded',
    'molder',
    'moldiness',
    'molding',
    'moldings',
    'moldova',
    'moldovan',
    'molds',
    'moldy',
    'mole',
    'molech',
    'molecular',
    'molecule',
    'molecules',
    'molehill',
    'moles',
    'moleskin',
    'molest',
    'molestation',
    'molested',
    'molester',
    'molidae',
    'moliere',
    'molindone',
    'moline',
    'molise',
    'moll',
    'mollah',
    'molle',
    'mollie',
    'mollienesia',
    'mollies',
    'mollification',
    'mollify',
    'molluga',
    'mollusc',
    'mollusca',
    'molluscs',
    'molluscum',
    'mollusk',
    'mollusks',
    'molly',
    'mollycoddle',
    'mollycoddler',
    'mollymawk',
    'molnar',
    'moloch',
    'molokai',
    'molossidae',
    'molothrus',
    'molotov',
    'molt',
    'molted',
    'molten',
    'molter',
    'molting',
    'molts',
    'moluccas',
    'molucella',
    'molva',
    'molybdenite',
    'molybdenum',
    'mom',
    'mombasa',
    'mombin',
    'moment',
    'momentaneous',
    'momentarily',
    'momentary',
    'momentous',
    'momentousness',
    'moments',
    'momentum',
    'momism',
    'momma',
    'mommsen',
    'mommy',
    'momordica',
    'momos',
    'momot',
    'momotidae',
    'momotus',
    'momus',
    'mon',
    'mona',
    'monacan',
    'monaco',
    'monad',
    'monads',
    'monal',
    'monals',
    'monandrous',
    'monandry',
    'monarch',
    'monarchal',
    'monarchic',
    'monarchical',
    'monarchism',
    'monarchist',
    'monarchs',
    'monarchy',
    'monarda',
    'monardella',
    'monario',
    'monas',
    'monasteries',
    'monastery',
    'monastic',
    'monastical',
    'monasticism',
    'monatomic',
    'monaul',
    'monaural',
    'monazite',
    'monday',
    'mondays',
    'mondrian',
    'monecious',
    'monegasque',
    'monera',
    'moneran',
    'monerans',
    'moneron',
    'moneses',
    'monestrous',
    'monet',
    'monetarism',
    'monetarist',
    'monetary',
    'monetisation',
    'monetise',
    'monetization',
    'monetize',
    'monetized',
    'money',
    'moneybag',
    'moneyed',
    'moneyer',
    'moneygrubber',
    'moneylender',
    'moneyless',
    'moneymaker',
    'moneymaking',
    'moneyman',
    'moneywort',
    'monger',
    'monggo',
    'mongo',
    'mongol',
    'mongolia',
    'mongolian',
    'mongolianism',
    'mongolic',
    'mongolism',
    'mongoloid',
    'mongols',
    'mongoose',
    'mongooses',
    'mongrel',
    'mongrelise',
    'mongrelize',
    'monied',
    'moniker',
    'monilia',
    'moniliaceae',
    'moniliales',
    'moniliasis',
    'monish',
    'monism',
    'monistat',
    'monistic',
    'monition',
    'monitor',
    'monitored',
    'monitoring',
    'monitors',
    'monitory',
    'monitrice',
    'monk',
    'monkey',
    'monkeypod',
    'monkeys',
    'monkfish',
    'monkish',
    'monks',
    'monkshood',
    'monmouth',
    'monnet',
    'mono',
    'monoamine',
    'monoamines',
    'monoatomic',
    'monobasic',
    'monoblast',
    'monoblasts',
    'monocanthidae',
    'monocanthus',
    'monocarboxylic',
    'monocarp',
    'monocarpic',
    'monochamus',
    'monochromacy',
    'monochromasy',
    'monochromat',
    'monochromatic',
    'monochromatism',
    'monochrome',
    'monochromia',
    'monochromic',
    'monochromous',
    'monocle',
    'monocled',
    'monoclinal',
    'monocline',
    'monoclinic',
    'monoclinous',
    'monoclonal',
    'monocot',
    'monocotyledon',
    'monocotyledonae',
    'monocotyledones',
    'monocotyledonous',
    'monocracy',
    'monoculture',
    'monocycle',
    'monocyte',
    'monocytes',
    'monocytic',
    'monocytosis',
    'monod',
    'monodic',
    'monodical',
    'monodon',
    'monodontidae',
    'monody',
    'monoecious',
    'monoestrous',
    'monogamist',
    'monogamous',
    'monogamousness',
    'monogamy',
    'monogenesis',
    'monogenic',
    'monogram',
    'monograph',
    'monogynic',
    'monogynist',
    'monogynous',
    'monogyny',
    'monohybrid',
    'monohydrate',
    'monoicous',
    'monolatry',
    'monolingual',
    'monolith',
    'monolithic',
    'monologist',
    'monologue',
    'monologues',
    'monologuise',
    'monologuize',
    'monomania',
    'monomaniac',
    'monomaniacal',
    'monomer',
    'monomers',
    'monometallic',
    'monomorium',
    'monomorphemic',
    'mononeuropathy',
    'monongahela',
    'mononuclear',
    'mononucleate',
    'mononucleosis',
    'monophonic',
    'monophony',
    'monophthalmos',
    'monophysite',
    'monophysitic',
    'monophysitism',
    'monoplane',
    'monoplegia',
    'monoploid',
    'monopolies',
    'monopolisation',
    'monopolise',
    'monopoliser',
    'monopolist',
    'monopolistic',
    'monopolization',
    'monopolize',
    'monopolizer',
    'monopolizes',
    'monopoly',
    'monopsony',
    'monopteral',
    'monorail',
    'monorchidism',
    'monorchism',
    'monosaccharide',
    'monosaccharides',
    'monosaccharose',
    'monosemous',
    'monosemy',
    'monosodium',
    'monosomy',
    'monosperma',
    'monosyllabic',
    'monosyllable',
    'monotheism',
    'monotheist',
    'monotheistic',
    'monothelitism',
    'monotone',
    'monotones',
    'monotonic',
    'monotonous',
    'monotonously',
    'monotony',
    'monotremata',
    'monotreme',
    'monotremes',
    'monotropa',
    'monotropaceae',
    'monotype',
    'monotypic',
    'monounsaturated',
    'monovalent',
    'monovular',
    'monoxide',
    'monozygotic',
    'monro',
    'monroe',
    'monrovia',
    'mons',
    'monsieur',
    'monsignor',
    'monsoon',
    'monster',
    'monstera',
    'monsters',
    'monstrance',
    'monstrosity',
    'monstrous',
    'mont',
    'montage',
    'montagu',
    'montaigne',
    'montana',
    'montanan',
    'montane',
    'monte',
    'montenegro',
    'monterey',
    'monterrey',
    'montespan',
    'montesquieu',
    'montessori',
    'monteverdi',
    'montevideo',
    'montez',
    'montezuma',
    'montfort',
    'montgolfier',
    'montgomery',
    'month',
    'monthlong',
    'monthly',
    'months',
    'montia',
    'montmartre',
    'montpelier',
    'montrachet',
    'montreal',
    'montserrat',
    'montserratian',
    'monument',
    'monumental',
    'monumentalise',
    'monumentalize',
    'monuments',
    'moo',
    'mooch',
    'moocher',
    'mooches',
    'mood',
    'moodily',
    'moodiness',
    'moods',
    'moody',
    'moolah',
    'moon',
    'moonbeam',
    'mooneye',
    'moonfish',
    'moonflower',
    'moong',
    'moonie',
    'moonies',
    'moonless',
    'moonlight',
    'moonlighter',
    'moonlighting',
    'moonlike',
    'moonlit',
    'moons',
    'moonseed',
    'moonshell',
    'moonshells',
    'moonshine',
    'moonshiner',
    'moonstone',
    'moonstruck',
    'moonwalk',
    'moonwort',
    'moony',
    'moor',
    'moorage',
    'moorbird',
    'moorcock',
    'moore',
    'moored',
    'moorfowl',
    'moorgame',
    'moorhen',
    'mooring',
    'moorish',
    'moorland',
    'moors',
    'moorwort',
    'moose',
    'moosewood',
    'moot',
    'mop',
    'mopboard',
    'mope',
    'moped',
    'mopes',
    'mopped',
    'mopper',
    'moppet',
    'mopping',
    'moquelumnan',
    'moquette',
    'moraceae',
    'moraceous',
    'moraine',
    'moral',
    'morale',
    'moralisation',
    'moralise',
    'moralism',
    'moralist',
    'moralistic',
    'morality',
    'moralization',
    'moralize',
    'moralizing',
    'morally',
    'morals',
    'morass',
    'moratorium',
    'moravia',
    'moravian',
    'moray',
    'morbid',
    'morbidity',
    'morbidly',
    'morbidness',
    'morbific',
    'morbilli',
    'morbilliform',
    'morceau',
    'morchella',
    'morchellaceae',
    'mordacious',
    'mordacity',
    'mordant',
    'mordva',
    'mordvin',
    'mordvinian',
    'mordvinians',
    'more',
    'moreen',
    'morel',
    'morello',
    'morels',
    'mores',
    'moresque',
    'moreton',
    'morgan',
    'morganatic',
    'morganite',
    'morgantown',
    'morgen',
    'morgue',
    'moribund',
    'morion',
    'morley',
    'mormon',
    'mormonism',
    'mormons',
    'morn',
    'mornay',
    'morning',
    'moro',
    'moroccan',
    'morocco',
    'moron',
    'morone',
    'moronic',
    'moronity',
    'morose',
    'moroseness',
    'morosoph',
    'morph',
    'morphallaxis',
    'morphea',
    'morphed',
    'morpheme',
    'morphemes',
    'morphemic',
    'morpheus',
    'morphia',
    'morphine',
    'morphogenesis',
    'morphologic',
    'morphological',
    'morphology',
    'morphophoneme',
    'morphophonemic',
    'morphophonemics',
    'morphophysiology',
    'morrigan',
    'morrigu',
    'morris',
    'morrison',
    'morristown',
    'morrow',
    'mors',
    'morse',
    'morsel',
    'mortal',
    'mortality',
    'mortally',
    'mortals',
    'mortar',
    'mortarboard',
    'mortars',
    'mortgage',
    'mortgaged',
    'mortgagee',
    'mortgager',
    'mortgages',
    'mortgagor',
    'mortgagors',
    'mortice',
    'mortician',
    'mortification',
    'mortified',
    'mortify',
    'mortifying',
    'mortimer',
    'mortise',
    'mortised',
    'mortises',
    'mortmain',
    'morton',
    'mortuary',
    'morula',
    'morus',
    'mosaic',
    'mosaicism',
    'mosaics',
    'mosan',
    'mosander',
    'moschata',
    'moschus',
    'moscow',
    'moselle',
    'moses',
    'mosey',
    'mosh',
    'moshav',
    'moslem',
    'moslems',
    'mosque',
    'mosques',
    'mosquito',
    'mosquitoes',
    'mosquitofish',
    'mosquitos',
    'moss',
    'mossad',
    'mossback',
    'mossbauer',
    'mosses',
    'mosstone',
    'mossy',
    'most',
    'mostaccioli',
    'mostly',
    'mosul',
    'mot',
    'motacilla',
    'motacillidae',
    'mote',
    'motel',
    'motet',
    'moth',
    'mothball',
    'mothballs',
    'mother',
    'motherese',
    'motherfucker',
    'motherhood',
    'motherland',
    'motherless',
    'motherlike',
    'motherliness',
    'motherly',
    'mothers',
    'motherwell',
    'motherwort',
    'mothproof',
    'moths',
    'mothy',
    'motif',
    'motifs',
    'motile',
    'motilin',
    'motility',
    'motion',
    'motional',
    'motionless',
    'motionlessness',
    'motions',
    'motivate',
    'motivated',
    'motivates',
    'motivating',
    'motivation',
    'motivational',
    'motivative',
    'motivator',
    'motive',
    'motiveless',
    'motives',
    'motivity',
    'motley',
    'motmot',
    'moto',
    'motoneuron',
    'motor',
    'motorbike',
    'motorboat',
    'motorbus',
    'motorcade',
    'motorcar',
    'motorcoach',
    'motorcycle',
    'motorcycles',
    'motorcycling',
    'motorcyclist',
    'motored',
    'motorial',
    'motoring',
    'motorisation',
    'motorise',
    'motorised',
    'motorist',
    'motorists',
    'motorization',
    'motorize',
    'motorized',
    'motorizing',
    'motorless',
    'motorman',
    'motormouth',
    'motors',
    'motortruck',
    'motorway',
    'motown',
    'motrin',
    'mott',
    'mottle',
    'mottled',
    'mottling',
    'motto',
    'moue',
    'moufflon',
    'mouflon',
    'moujik',
    'moukden',
    'mould',
    'mouldboard',
    'moulder',
    'moulding',
    'mouldy',
    'moulin',
    'moulmein',
    'moult',
    'moulter',
    'moulting',
    'mound',
    'mounded',
    'mounds',
    'mount',
    'mountain',
    'mountaineer',
    'mountaineering',
    'mountaineers',
    'mountainous',
    'mountains',
    'mountainside',
    'mountainsides',
    'mountebank',
    'mounted',
    'mounter',
    'mountie',
    'mounties',
    'mounting',
    'mounts',
    'mourn',
    'mourned',
    'mourner',
    'mourners',
    'mournful',
    'mournfulness',
    'mourning',
    'mouse',
    'mouselike',
    'mousepad',
    'mouser',
    'mousetrap',
    'mousey',
    'mousing',
    'moussaka',
    'mousse',
    'mousses',
    'moussorgsky',
    'moustache',
    'moustaches',
    'moustachio',
    'mousy',
    'mouth',
    'mouthbreeder',
    'mouthed',
    'mouthful',
    'mouthfuls',
    'mouthless',
    'mouthlike',
    'mouthpart',
    'mouthparts',
    'mouthpiece',
    'mouths',
    'mouthwash',
    'mouton',
    'movability',
    'movable',
    'movableness',
    'move',
    'moveable',
    'moved',
    'movement',
    'movements',
    'mover',
    'movers',
    'moves',
    'movie',
    'moviegoer',
    'moviemaking',
    'movies',
    'moving',
    'mow',
    'mowat',
    'mowed',
    'mower',
    'mowing',
    'mown',
    'moxie',
    'moynihan',
    'mozambican',
    'mozambique',
    'mozart',
    'mozartean',
    'mozartian',
    'mozzarella',
    'mp',
    'mpeg',
    'mph',
    'mps',
    'mr',
    'mrd',
    'mrem',
    'mri',
    'mrna',
    'mrs',
    'mrta',
    'ms',
    'msasa',
    'msb',
    'msc',
    'msec',
    'msg',
    'msh',
    'mst',
    'mt',
    'mu',
    'muadhdhin',
    'muazzin',
    'mubarak',
    'much',
    'muchness',
    'muciferous',
    'mucilage',
    'mucilaginous',
    'mucin',
    'mucinoid',
    'mucinous',
    'muck',
    'mucked',
    'muckheap',
    'muckhill',
    'mucking',
    'muckle',
    'muckrake',
    'muckraker',
    'muckraking',
    'mucky',
    'mucocutaneous',
    'mucoid',
    'mucoidal',
    'mucopolysaccharide',
    'mucopolysaccharides',
    'mucopolysaccharidosis',
    'mucopurulent',
    'mucor',
    'mucoraceae',
    'mucorales',
    'mucosa',
    'mucosal',
    'mucose',
    'mucous',
    'mucoviscidosis',
    'mucuna',
    'mucus',
    'mud',
    'mudcat',
    'mudder',
    'muddied',
    'muddiness',
    'muddle',
    'muddled',
    'muddleheaded',
    'muddy',
    'mudguard',
    'mudhif',
    'mudra',
    'mudras',
    'mudskipper',
    'mudslide',
    'mudslinger',
    'mudspringer',
    'mudwrestle',
    'muenchen',
    'muenster',
    'muesli',
    'muezzin',
    'muff',
    'muffed',
    'muffet',
    'muffin',
    'muffins',
    'muffle',
    'muffled',
    'muffler',
    'mufti',
    'mug',
    'mugful',
    'mugged',
    'muggee',
    'mugger',
    'muggers',
    'mugginess',
    'mugging',
    'muggins',
    'muggy',
    'mughals',
    'mugil',
    'mugilidae',
    'mugiloidea',
    'mugshot',
    'mugwort',
    'mugwump',
    'muhammad',
    'muhammadan',
    'muhammadanism',
    'muhammedan',
    'muharram',
    'muharrum',
    'muhlenbergia',
    'muir',
    'muishond',
    'muishonds',
    'mujahadeen',
    'mujahadein',
    'mujahadin',
    'mujahedeen',
    'mujahedin',
    'mujahid',
    'mujahideen',
    'mujahidin',
    'mujik',
    'mujtihad',
    'mukalla',
    'mukataa',
    'mukden',
    'mukhabarat',
    'mulatto',
    'mulberries',
    'mulberry',
    'mulch',
    'mulct',
    'mule',
    'mules',
    'muleteer',
    'muliebrity',
    'mulish',
    'mulishness',
    'mull',
    'mulla',
    'mullah',
    'mullahs',
    'mulled',
    'mullein',
    'muller',
    'mullet',
    'mullets',
    'mullidae',
    'mulligan',
    'mulligatawny',
    'mullion',
    'mullioned',
    'mulloidichthys',
    'mulloway',
    'mullus',
    'multicellular',
    'multicollinearity',
    'multicolor',
    'multicolored',
    'multicolour',
    'multicoloured',
    'multicultural',
    'multiculturalism',
    'multidimensional',
    'multiethnic',
    'multifaceted',
    'multifactorial',
    'multifarious',
    'multifariousness',
    'multiflora',
    'multiform',
    'multilane',
    'multilateral',
    'multilevel',
    'multilingual',
    'multimedia',
    'multinational',
    'multinomial',
    'multinucleate',
    'multiparous',
    'multipartite',
    'multiphase',
    'multiple',
    'multiples',
    'multiplex',
    'multiplexer',
    'multiplicand',
    'multiplication',
    'multiplicative',
    'multiplicity',
    'multiplied',
    'multiplier',
    'multiply',
    'multiplying',
    'multipotent',
    'multiprocessing',
    'multiprocessor',
    'multiprogramming',
    'multipurpose',
    'multiracial',
    'multistage',
    'multistorey',
    'multistoried',
    'multistory',
    'multitude',
    'multitudes',
    'multitudinous',
    'multitudinousness',
    'multivalence',
    'multivalency',
    'multivalent',
    'multivariate',
    'multiversity',
    'multivitamin',
    'mulwi',
    'mum',
    'mumbai',
    'mumble',
    'mumbled',
    'mumbler',
    'mumbling',
    'mumford',
    'mummer',
    'mummery',
    'mummichog',
    'mummification',
    'mummified',
    'mummify',
    'mummy',
    'mumps',
    'mumpsimus',
    'munch',
    'munchausen',
    'munchener',
    'muncher',
    'munches',
    'munchhausen',
    'munching',
    'muncie',
    'munda',
    'mundane',
    'mundaneness',
    'mundanity',
    'mung',
    'munggo',
    'munich',
    'municipal',
    'municipalities',
    'municipality',
    'munificence',
    'munificent',
    'muniments',
    'munition',
    'munitions',
    'munj',
    'munja',
    'munjeet',
    'munjuk',
    'munro',
    'muntiacus',
    'muntingia',
    'muntjac',
    'muntjacs',
    'muon',
    'muons',
    'muraenidae',
    'mural',
    'muralist',
    'murals',
    'muramidase',
    'murder',
    'murdered',
    'murderee',
    'murderer',
    'murderess',
    'murdering',
    'murderous',
    'murderousness',
    'murders',
    'murdoch',
    'muridae',
    'murillo',
    'murine',
    'muritaniya',
    'murk',
    'murkiness',
    'murky',
    'murmansk',
    'murmur',
    'murmuration',
    'murmured',
    'murmurer',
    'murmuring',
    'murmurous',
    'muroidea',
    'murphy',
    'murrain',
    'murray',
    'murre',
    'murres',
    'murrow',
    'murrumbidgee',
    'mus',
    'musa',
    'musaceae',
    'musales',
    'musca',
    'muscadel',
    'muscadelle',
    'muscadet',
    'muscadine',
    'muscardinus',
    'muscari',
    'muscat',
    'muscatel',
    'musci',
    'muscicapa',
    'muscicapidae',
    'muscidae',
    'muscivora',
    'muscle',
    'musclebuilder',
    'musclebuilding',
    'muscled',
    'muscleman',
    'muscles',
    'muscoidea',
    'muscovite',
    'muscovy',
    'muscular',
    'muscularity',
    'musculature',
    'musculoskeletal',
    'musculus',
    'musd',
    'muse',
    'muser',
    'muses',
    'musette',
    'museum',
    'museums',
    'musgoi',
    'musgu',
    'mush',
    'musher',
    'mushiness',
    'mushroom',
    'mushrooming',
    'mushrooms',
    'mushy',
    'musial',
    'music',
    'musical',
    'musicality',
    'musically',
    'musicalness',
    'musicals',
    'musician',
    'musicians',
    'musicianship',
    'musicological',
    'musicologist',
    'musicology',
    'musing',
    'musings',
    'musjid',
    'musk',
    'muskat',
    'muskellunge',
    'muskellunges',
    'musket',
    'musketeer',
    'musketeers',
    'musketry',
    'muskets',
    'muskhogean',
    'muskiness',
    'muskmelon',
    'muskmelons',
    'muskogean',
    'muskogee',
    'muskrat',
    'muskrats',
    'muskwood',
    'musky',
    'muslim',
    'muslimah',
    'muslimism',
    'muslims',
    'muslin',
    'musnud',
    'musophaga',
    'musophagidae',
    'musophobia',
    'musquash',
    'muss',
    'mussed',
    'mussel',
    'mussels',
    'musset',
    'mussiness',
    'mussitate',
    'mussitation',
    'mussolini',
    'mussorgsky',
    'mussy',
    'must',
    'mustache',
    'mustached',
    'mustaches',
    'mustachio',
    'mustachioed',
    'mustagh',
    'mustang',
    'mustard',
    'mustela',
    'mustelid',
    'mustelidae',
    'mustelids',
    'musteline',
    'mustelus',
    'muster',
    'mustering',
    'musth',
    'mustiness',
    'musty',
    'mutability',
    'mutable',
    'mutableness',
    'mutafacient',
    'mutagen',
    'mutagenesis',
    'mutagenic',
    'mutamycin',
    'mutant',
    'mutate',
    'mutated',
    'mutation',
    'mutational',
    'mutations',
    'mutative',
    'mutawa',
    'mutchkin',
    'mute',
    'muted',
    'muteness',
    'mutilate',
    'mutilated',
    'mutilates',
    'mutilation',
    'mutilator',
    'mutillidae',
    'mutineer',
    'mutineers',
    'mutinied',
    'mutinies',
    'mutinous',
    'mutinus',
    'mutiny',
    'mutisia',
    'mutism',
    'muton',
    'mutsuhito',
    'mutt',
    'mutter',
    'mutterer',
    'muttering',
    'mutton',
    'muttonfish',
    'muttonhead',
    'mutual',
    'mutualism',
    'mutualist',
    'mutuality',
    'mutually',
    'mutualness',
    'muumuu',
    'muybridge',
    'muzhik',
    'muzjik',
    'muztag',
    'muztagh',
    'muzzle',
    'muzzler',
    'muzzles',
    'muzzy',
    'mv',
    'mvp',
    'mwanza',
    'mwera',
    'mx',
    'my',
    'mya',
    'myaceae',
    'myacidae',
    'myadestes',
    'myalgia',
    'myalgic',
    'myanmar',
    'myasthenia',
    'mycelium',
    'mycenae',
    'mycenaean',
    'mycenaen',
    'mycetophilidae',
    'mycobacteria',
    'mycobacteriaceae',
    'mycobacterium',
    'mycologist',
    'mycology',
    'mycomycin',
    'mycophage',
    'mycophagist',
    'mycophagy',
    'mycoplasma',
    'mycoplasmataceae',
    'mycoplasmatales',
    'mycosis',
    'mycostatin',
    'mycotoxin',
    'mycrosporidia',
    'mycteria',
    'mycteroperca',
    'myctophidae',
    'mydriasis',
    'mydriatic',
    'myelatelia',
    'myelencephalon',
    'myelic',
    'myelin',
    'myelinated',
    'myeline',
    'myelinic',
    'myelinisation',
    'myelinization',
    'myelitis',
    'myeloblast',
    'myeloblasts',
    'myelocyte',
    'myelocytes',
    'myelofibrosis',
    'myelogram',
    'myelography',
    'myeloid',
    'myeloma',
    'myelomeningocele',
    'myg',
    'myiasis',
    'mylanta',
    'mylar',
    'myliobatidae',
    'mylitta',
    'mylodon',
    'mylodontid',
    'mylodontidae',
    'mym',
    'myna',
    'mynah',
    'mynas',
    'myocardial',
    'myocardiopathy',
    'myocarditis',
    'myocardium',
    'myocastor',
    'myoclonus',
    'myodynia',
    'myofibril',
    'myofibrilla',
    'myoglobin',
    'myoglobinuria',
    'myogram',
    'myoid',
    'myology',
    'myoma',
    'myometritis',
    'myometrium',
    'myomorpha',
    'myonecrosis',
    'myoneural',
    'myopathic',
    'myopathy',
    'myope',
    'myopia',
    'myopic',
    'myopus',
    'myosarcoma',
    'myosin',
    'myosis',
    'myositis',
    'myosotis',
    'myotic',
    'myotis',
    'myotomy',
    'myotonia',
    'myotonic',
    'myrcia',
    'myrciaria',
    'myrdal',
    'myriad',
    'myriagram',
    'myriameter',
    'myriametre',
    'myriapod',
    'myriapoda',
    'myrica',
    'myricaceae',
    'myricales',
    'myricaria',
    'myringa',
    'myringectomy',
    'myringoplasty',
    'myringotomy',
    'myriophyllum',
    'myristica',
    'myristicaceae',
    'myrmecia',
    'myrmecobius',
    'myrmecophaga',
    'myrmecophagidae',
    'myrmecophagous',
    'myrmecophile',
    'myrmecophilous',
    'myrmecophyte',
    'myrmecophytes',
    'myrmecophytic',
    'myrmeleon',
    'myrmeleontidae',
    'myrmidon',
    'myrmidons',
    'myrobalan',
    'myroxylon',
    'myrrh',
    'myrrhis',
    'myrsinaceae',
    'myrsine',
    'myrtaceae',
    'myrtales',
    'myrtillocactus',
    'myrtle',
    'myrtus',
    'myself',
    'mysidacea',
    'mysidae',
    'mysis',
    'mysoandry',
    'mysoline',
    'mysophilia',
    'mysophobia',
    'mysophobic',
    'mysore',
    'mysteries',
    'mysterious',
    'mysteriously',
    'mystery',
    'mystic',
    'mystical',
    'mysticeti',
    'mysticism',
    'mystification',
    'mystified',
    'mystifier',
    'mystify',
    'mystifying',
    'mystique',
    'myth',
    'mythic',
    'mythical',
    'mythicise',
    'mythicize',
    'mythicized',
    'mythologic',
    'mythological',
    'mythologisation',
    'mythologise',
    'mythologist',
    'mythologization',
    'mythologize',
    'mythologized',
    'mythology',
    'myths',
    'mytilene',
    'mytilid',
    'mytilidae',
    'mytilus',
    'myung',
    'myxedema',
    'myxine',
    'myxinidae',
    'myxiniformes',
    'myxinikela',
    'myxinoidea',
    'myxinoidei',
    'myxobacter',
    'myxobacterales',
    'myxobacteria',
    'myxobacteriaceae',
    'myxobacteriales',
    'myxobacterium',
    'myxocephalus',
    'myxoedema',
    'myxoma',
    'myxomatosis',
    'myxomycete',
    'myxomycetes',
    'myxomycota',
    'myxophyceae',
    'myxosporidia',
    'myxosporidian',
    'myxovirus']



# -*- coding: utf-8 -*-
""" Text Utility Methods: Common Functions without Special Libraries """


from os import sep
from statistics import mean
from typing import List, Optional

from unicodedata2 import category

STOPWORDS = [
    'a',
    'all',

    'for',
    'from',

    'of',

    'i',
    'in',
    'into',
    'is',

    'to',
    'the',
]

# TODO: Improve from https://github.com/craigtrim/baseblock
class TextUtils(object):
    """ Text Utility Methods: Common Functions without Special Libraries """

    @staticmethod
    def remove_duplicated_phrases(text_1: str,
                                  text_2: str) -> str:
        """ Remove Duplicated Phrases

        Purpose:
        -   Any Phrase in Text_2 that exists in Text_1 will cause
            that phrase to be removed from Text_1

        Args:
            text_1 (str): the text to modify
            text_2 (str): the read-only text to use for removal

        Returns:
            str: the modified text_1 (if applicable)
        """

        if text_2 in text_1:
            text_1 = text_1.replace(text_2, '').strip()

        return text_1

    """
    TODO: Write Test
    @staticmethod
    def cartesian(matches: list) -> list:
        ---
        Purpose:
            Find a list of candidate token sequences within the normalized_input_text
        Time per Call:
            0.5ms < x 1.0ms
        :param matches:
            a list of 1..* tokens forming a match pattern
        :return:
            a list of possible token sequences
        ---
        from itertools import product

        cartesian = []
        for element in product(*matches):
            cartesian.append(element)

        return cartesian
    """
    @staticmethod
    def sliding_window(tokens: List[str],
                       window_size: int) -> Optional[List[str]]:
        """ Perform Sliding Window (e.g., n-gram) extraction over a list of tokens

        Args:
            tokens (List[str]): the incoming tokens
            window_size (int): the window (e.g., n-gram) size

        Returns:
            Optional[List[str]]: the outgoing tokens (if any)
        """

        if window_size > len(tokens):
            return None

        if window_size == len(tokens):
            return [tokens]

        results = []
        total_tokens = len(tokens)

        for i in range(total_tokens):

            buffer = []

            x = 0
            while x < window_size:

                pos = x + i
                if pos < total_tokens:
                    buffer.append(tokens[pos])

                x += 1

            if len(buffer) == window_size:
                results.append(buffer)
                buffer = []

        return results

    @staticmethod
    def most_similar_phrase(tokens_1: List[str],
                            tokens_2: List[str],
                            window_size: int,
                            score_threshold: float,
                            debug: bool = False) -> dict:
        """ Find the Most Similar Phrase in Tokens-2 relative to Tokens-1

        Implementation Note:
            How is this different from 'longest-common-phrase'?

            In the example below, there are no common sequences between tokens-1 and tokens-2
            This function will find "nearly similar" sequences and return the most similar

        Args:
            tokens_1 (list): the first tokenized list
                ['where', 'is', 'the', 'library', '?']
            tokens_2 (list): the second tokenized list
                ['I', 'understand', 'you', 'want', 'to', 'know', 'where', 'the', 'library', 'is', '.']
            window_size (int, Optional): n-Gram window size for comparison.
            score_threshold (float): when threshold is met, return the results (if any)
            debug (bool, Optional): When True, print results to console. default is False.

        Returns:
            the most similar span (list) with similarity score
        """

        tokens_1 = [x.lower().strip() for x in tokens_1]
        tokens_2 = [x.lower().strip() for x in tokens_2]

        t1 = TextUtils.sliding_window(
            tokens_1,
            window_size=window_size)

        t2 = TextUtils.sliding_window(
            tokens_2,
            window_size=window_size)

        d_results = {}

        for item_1 in [' '.join(x) for x in t1]:
            for item_2 in [' '.join(x) for x in t2]:

                if item_1 == item_2:
                    return {100: {'tokens_1': item_1, 'tokens_2': item_2}}

                score = TextUtils.jaccard_similarity(item_1, item_2)
                if debug:
                    print(f'({item_1}) vs. ({item_2}) = {score}')

                if score >= score_threshold:
                    d_results[score] = {'tokens_1': item_1, 'tokens_2': item_2}

        return d_results

    @staticmethod
    def longest_common_phrase(tokens_1: List[str],
                              tokens_2: List[str]) -> Optional[List[str]]:
        """ Find the Longest Common Phrase in Tokens-2 relative to Tokens-1

        Args:
            tokens_1 (list): the first tokenized list
                ['what', 'is', 'the', 'earliest', 'known', 'age', 'of', 'fossils', '?']
            tokens_2 (list): the second tokenized list
                ['the', 'earliest', 'known', 'age', 'of', 'fossils', 'is', '3.7', 'billion', 'years', 'old', '.']

        Returns:
            Optional[List[str]]: the common span (if any)
                ['the', 'earliest', 'known', 'age', 'of', 'fossils']
        """

        text_2 = ' '.join(tokens_2).strip()

        def extract(tokens: list,
                    gram_size: int) -> set:
            results = []

            if gram_size == len(tokens):
                return set([' '.join(x) for x in tokens])

            # Never call
            #if gram_size == 1:
            #    return set([' '.join(x) for x in tokens])

            x = 0
            y = x + gram_size

            while y <= len(tokens):
                results.append(tokens[x: y])

                x += 1
                y = x + gram_size

            return set([' '.join(x) for x in results])

        max_tokens = min([len(tokens_1), len(tokens_2)])

        while max_tokens > 2:

            extracts_1 = extract(tokens_1, max_tokens)
            extracts_2 = extract(tokens_2, max_tokens)

            common = extracts_1.intersection(extracts_2)
            if common:

                common_phrase = list(common)[0]
                if common_phrase not in text_2.lower():
                    return None

                x = text_2.lower().index(common_phrase)
                y = x + len(common_phrase)

                return text_2[x: y].split()

            max_tokens -= 1

        return None

    @ staticmethod
    def is_punctuation(char: str) -> bool:
        """ Checks whether `char` is a punctuation character.

        Args:
            char (str): any incoming character
                if the length of the parameter exceeds 1, this method will return False immediately

        Returns:
            bool: True if the character is punctuation
        """

        # not testing if 'has_punctuation'
        if len(char) > 1:
            return False

        cp = ord(char)

        # We treat all non-letter/number ASCII as punctuation.
        # Characters such as "^", "$", and "`" are not in the Unicode
        # Punctuation class but we treat them as punctuation anyways, for consistency.
        result = False
        if (cp >= 33 and cp <= 47) or (cp >= 58 and cp <= 64) or (cp >= 91 and cp <= 96) or (cp >= 123 and cp <= 126):
            result = True

        cat = category(char)
        if cat.startswith('P'):
            result = True

        return result

    @ staticmethod
    def has_punctuation(input_text: str):
        """Checks whether the input text has any punctuation characters."""

        for ch in input_text:
            if TextUtils.is_punctuation(ch):
                return True

        return False

    @ staticmethod
    def remove_punctuation(input_text: str):
        """Checks whether the input text has any punctuation characters."""

        buffer = []
        for ch in input_text:
            if not TextUtils.is_punctuation(ch):
                buffer.append(ch)

        return ''.join(buffer)

    @ staticmethod
    def find_subsumed_tokens(tokens: list) -> list:
        """ Find Subsumed Tokens (if any)

        Version:
            >= 0.1.6

        For Example:
            '1 pm' contains 'pm' thus '1 pm' subsumes (asorbs) 'pm'

        Reference:


        Args:
            tokens (list): the incoming tokens
            Sample Input:
                ['tomorrow', 'meeting', '1 pm', 'pm']

        Returns:
            list: the subsumed tokens (if any)
            Sample Output:
                ['pm']
        """

        def exists(item_1: str, item_2: str) -> bool:
            token_lr = f' {item_1} '
            if token_lr in item_2:
                return True

            token_l = f' {item_1}'
            if item_2.endswith(token_l):
                return True

            token_r = f'{item_1} '
            if item_2.startswith(token_r):
                return True

            return False

        pairs = []
        for i1 in tokens:
            for i2 in [x for x in tokens if i1 != x]:
                pairs.append(sorted({i1, i2}, reverse=False))

        excludes = set()
        for pair in pairs:
            if exists(pair[0], pair[1]):
                excludes.add(pair[0])

        if not len(excludes):
            return []

        return sorted(excludes)

    """
    TODO: Fail Test... Fix Test First
    def choose_random_line(input_text: str) -> str:
        ---
        Choose Random Line from Long Input String

        The function will segment the input text and if only one line exists, this will be returned
        if multiple lines exist, the function will randomly choose a single line, assuming the length
            of that line is near the mean

        Use Case:

            Assume the input text is:
                "Hi!  How are you doing?  I'm here to help you"

            This segments into three sentences:
                [
                    "Hi!",
                    "How are you doing?",
                    "I'm here to help you",
                ]

            Either of the last two sentences will be chosen

        Args:
            input_text (str): the incoming text string

        Returns:
            str: a random segment from the incoming text string
        ---

        def random_line(lines: list) -> Optional[str]:
            try:
                d = {len(x): x for x in lines}
                _mean = mean(d)
                lines = list(reversed(d.values()))
                for i in len(lines):
                    if len(lines[i]) >= _mean - 2:
                        return lines[i]

                return lines[0]
            except Exception:
                print(lines)
                raise ValueError

        lines = TextUtils.split_on_punctuation(input_text)
        if len(lines) == 1:
            return lines[0]
        return random_line(lines)
    """

    @ staticmethod
    def jaccard_similarity(x: str, y: str) -> float:
        """ returns the jaccard similarity between two lists

        Args:
            x (str): the first string to compare
            y (str): the second string to compare

        Raises:
            ValueError: final score is less than 0.0
            ValueError: final score is greater than 0.0
            ValueError: final score is not of type float

        Returns:
            float: the Jaccard similarity score (0.0 <= x <= 1.0)
        """
        intersection_cardinality = len(set.intersection(*[set(x), set(y)]))
        union_cardinality = len(set.union(*[set(x), set(y)]))
        sim = intersection_cardinality / float(union_cardinality)
        result = round(sim, 3)

        # this is our contract to the consumer!
        if result < 0.0:
            raise ValueError
        if result > 1.0:
            raise ValueError
        if type(result) != float:
            raise ValueError

        return result

    @ staticmethod
    def split_on_len(input_text: str,
                     threshold: int = 7) -> Optional[str]:
        """Insert New Lines into Label Text
        This constrains the text to fit into a small box on a diagram

        Args:
            input_text (str): The text that will be displayed
            threshold (int, optional): The relative position to set a line break. Defaults to 7.

        Returns:
            Optional[str]: the input text with zero-or-more line breaks inserted
                only return None if the input is None
        """
        if input_text is None:
            return None

        if len(input_text) <= threshold:
            return input_text

        tokens = [x.strip() for x in input_text.split(' ')]

        master = []
        buffer = []
        for i in range(len(tokens)):
            buffer.append(tokens[i])

            temp = ' '.join(buffer).strip()
            if len(temp) >= threshold:
                master.append(temp)
                buffer = []

        if len(buffer):
            master.append(' '.join(buffer).strip())

        return sep.join(master).strip()

    @ staticmethod
    def ends_with_punctuation(input_text: str) -> bool:
        """ Determine if Input Text ends with punctuation

        Args:
            input_text (str): any input text of any length

        Returns:
            bool: True if punctuation ends the input text
        """
        if input_text is None or not len(input_text):
            return False

        return input_text[-1] in ['.', '?', '!']  # common ending punctuation

    @ staticmethod
    def remove_ending_punctuation(input_text: str) -> str:
        """ Remove Ending (terminating sequence) Punctuation

        Args:
            input_text (str): the input text of any length
            Sample Input:
                How are you doing?

        Returns:
            str: the input text with ending punctuation (if any) removed
            Sample Output:
                How are you doing
        """
        if TextUtils.ends_with_punctuation(input_text):
            return input_text[:-1]
        return input_text

    @ staticmethod
    def split_on_punctuation(input_text: str,
                             punkt: list = ['!', '?']) -> list:
        """ Split (segment) a line on common punctuation

        Args:
            input_text (str): the input text of any length
            punkt (list, optional): the punctuation to split on. Defaults to ['!', '?'].

        Returns:
            list: the split (segmented) input text
        """

        for p in punkt:
            input_text = input_text.replace(p, '.')

        lines = input_text.split('.')
        lines = [x.strip() for x in lines]
        lines = [x for x in lines if x and len(x)]

        return lines

    @ staticmethod
    def update_spacing(input_text: str) -> str:
        """ Correct Syntactical Spacing Inconsistencies

        Args:
            input_text (str): the input text of any length

        Returns:
            str: the corrected input string
        """
        input_text = input_text.replace(' !', '!')
        input_text = input_text.replace('.?', '?')
        input_text = input_text.replace('.!', '!')
        input_text = input_text.replace('. .', '. ').strip()

        while '  ' in input_text:
            input_text = input_text.replace('  ', ' ')

        return input_text

    @ staticmethod
    def remove_double_spaces(input_text: str) -> str:
        """ Remove Double Spaces in a String

        Args:
            input_text (str): the input text of any length

        Returns:
            str: the corrected input string
        """
        while '  ' in input_text:
            input_text = input_text.replace('  ', ' ')

        return input_text

    @ staticmethod
    def update_csvs(input_text: str) -> str:
        """ Synatically correct Comma Separated values in Natural Language
        TODO Write Test
        Samples:
            1.  Input:      meetings, presentations and speeches
                Output:     meetings, presentations, and speeches
            2.  Input:      the telephone, and electronic mail
                Output:     the telephone and electronic mail

        Args:
            input_text (str): the input text of any length

        Returns:
            str: the corrected input string
        """
        return input_text

    @ staticmethod
    def update_determiners(input_text: str) -> str:
        """ Update Determiners in a text string

        Args:
            input_text (str): the input text of any length
            Sample Input:
                "I see a elephant!"

        Returns:
            str: the corrected input string
            Sample Output:
                "I see an elephant!"
        """
        if ' ' not in input_text:
            return input_text

        results = []
        tokens = input_text.split(' ')

        for i in range(len(tokens)):

            def use_an() -> bool:
                if tokens[i].lower() != 'a':
                    return False

                if i + 1 >= len(tokens):
                    return False

                return TextUtils.startswith_vowel(tokens[i + 1])

            def an() -> str:
                if tokens[i].isupper():
                    return 'An'
                return 'an'

            if use_an():
                results.append(an())
            else:
                results.append(tokens[i])

        return ' '.join(results).strip()

    @ staticmethod
    def startswith_vowel(input_text: str) -> str:
        """ Determine if Input Text starts with a vowel

        Args:
            input_text (str): the input text of any length

        Returns:
            str: True if the input text does start with a vowel
        """
        vowels = ['a', 'e', 'i', 'o', 'u']

        if input_text[0] in ["'", '"'] and len(input_text) > 1:
            return input_text[1].lower() in vowels

        return input_text[0].lower() in vowels

    @ staticmethod
    def lower_case(input_text: str) -> str:
        """ Perform Lower Casing on Input

        Args:
            input_text (str): the input text of any length
            Sample Input:
                'The Quick Brown Fox Jumped OVER the Lazy Dog'

        Returns:
            str: the corrected input string
            Sample Output:
                'the quick brown fox jumped over the lazy dog'
        """
        if ' ' not in input_text:
            return input_text.lower()

        tokens = [x.lower() for x in input_text.split(' ')]

        return ' '.join(tokens).strip()

    @ staticmethod
    def sentence_case(input_text: str) -> str:
        """ Perform Sentence Casing on Input

        Args:
            input_text (str): the input text of any length
            Sample Input:
                'the quick brown fox jumped over the lazy dog'

        Returns:
            str: the corrected input string
            Sample Output:
                'The quick brown fox jumped over the lazy dog'
        """
        def case(value: str) -> str:
            return f'{value[:1].upper()}{value[1:]}'

        if ' ' not in input_text:
            return case(input_text)

        def conditional_case(value: str) -> str:

            # careful not to lowercase an acronym ...
            result = value
            if len(value) > 1 and not value.isupper():
                result = value.lower()

            return result

        tokens = input_text.split(' ')
        results = \
            [case(tokens[0])] + \
            [conditional_case(x) for x in tokens[1:]]

        return ' '.join(results).strip()

    @ staticmethod
    def title_case(input_text: str) -> str:
        """ Perform Title Casing on Input

        Args:
            input_text (str): the input text of any length
            Sample Input:
                'the quick brown fox jumped over the lazy dog'

        Returns:
            str: the corrected input string
            Sample Output:
                'The Quick Brown Fox Jumped Over the Lazy Dog'
        """
        def case(value: str) -> str:
            return f'{value[:1].upper()}{value[1:]}'

        def conditional_case(value: str) -> str:
            if value.lower().strip() in STOPWORDS:

                # careful not to lowercase an acronym ...
                if len(value) > 1 and not value.isupper():
                    return value.lower()

            return case(value)

        if ' ' not in input_text:
            return case(input_text)

        tokens = input_text.split(' ')
        results = \
            [case(tokens[0])] + \
            [conditional_case(x) for x in tokens[1:]]

        return ' '.join(results).strip()
